# Copyright Mandriva 2009, 2010 all rights reserved 

#!/bin/bash
#TEXTDOMAINDIR="/usr/lib/python2.6/site-packages/mss/agent/modules/locale"
#TEXTDOMAIN="functions"
#export TEXTDOMAINDIR TEXTDOMAIN

function set_locale_settings(){
    if [[ "$1"  &&  "$2" ]] ;then
	TEXTDOMAINDIR="$1"
        TEXTDOMAIN="$2"
    else
	local working_dir=`pwd -P`
	local module_dir=`expr match "$working_dir" "\(.*/modules/[^/]*\)"`
	TEXTDOMAINDIR=$module_dir/locale
	TEXTDOMAIN=`basename $module_dir`
    fi
    export TEXTDOMAIN TEXTDOMAINDIR
}


#working_dir=`pwd`
#modules_dir=`expr match "$working_dir" "\(.*agent/modules\)"`
modules_dir=$( cd -P "$( dirname "${BASH_SOURCE[0]}" )" && pwd ) #"
set_locale_settings "$modules_dir/locale" "functions"

# message types in RSS 
#0 : default 
#1 : warning  
#2 : error 
#7 : info  
#8 : info (bold output)
_T_DEFAULT=0
_T_WARNING=1
_T_ERROR=2
_T_INFO=7
_T_BOLD_INFO=8


# input
#	$1: message type
#	$2: text in a printf format
#	$3-${<max>}: parameters for printf - optional
# output: message adapted to RSS
function _T(){
    if [[ "$1" =~ ^[0-9]+$ ]]; then
	local type="$1"
    else
	eval local type='${'$1'}'
    fi
    if [ -z "$type" ]; then
	type="0"
    fi
    
    local text="$2"
    shift;
    shift;
    printf "$type$text\n" "$@"
}


# input
#	$1: path to config file/dir
# output: information about ldap configuration state
# return: error code
function check_ldap_config(){
    local config="$1"
    if [ ! -e "$config" ]; then
	echo $"%s configuration doesn't exist: %s" "LDAP" "$config"
	return 1
    fi
    
    flag="-F"
    if [ -f "$config" ]; then
	flag="-f"	
    fi
        
    slaptest -u $flag "$config"  > /dev/null 2>&1
    if [ $? -ne 0 ]; then
	_T 0 $"%s configuration has errors: %s" "LDAP" "$config"
	return 2
    fi
    
    return 0
}

function check_ldap_config_critically(){
    check_ldap_config "$1"
    if [ $? -gt 0 ]; then
	exit 1
    fi
}

function check_host_fqdn(){
    local fqdn=`hostname -f 2>/dev/null`
    if [ -z "$fqdn" ]; then
	_T 2 $"Failed to get %s for the current host" FQDN
	_T 2 $"Command %s returns nothing" "'hostname -f'"
	_T 2 $"%s for the current host can be changed e.g. via editing records in %s file" FQDN "/etc/hosts"
	exit 1
    fi
    internal_ips=`ifconfig | grep "inet addr" | sed 's/\:/ /'|awk '{print $3}'`
    host_ips=`hostname -i`

    for host_ip in $host_ips ; do
	for internal_ip in $internal_ips ; do
	    if [ "$host_ip" = "$internal_ip" ]; then
		return
	    fi
	done
    done
    _T 2 $"Test of the current host %s has been finished with errors" FQDN
    _T 2 $"Host %s is already present in an external network" "$fqdn"
    _T 2 $"%s for the current host can be changed e.g. via editing records in %s file" FQDN "/etc/hosts"

    exit 2
}

# input
#	$1: path to dir
# output: path to a backup copy of dir
# return: error code
function mybackup_dir(){
    local now=`date +%s`
    if [ ! -d "$1" ]; then
	_T 0 $"No directory to backup: %s" "$1" >&2
	return 1
    fi
    
    local newname="$1-backup-$now"
    cp -Rf $1 $newname
    if [ $? -ne 0 ]; then
        _T 0 $"Failed to make a backup copy for %s" "$1" >&2
        return 2
    fi
    echo "$newname"
    return 0
}


# input
#	$1: path to dir
# output: information about a backup process
# return: error code
function backup_dir(){
    local backup_dir=""
    backup_dir=`mybackup_dir $1`
    res=$?
    if [ $res -eq 0 ]; then
	_T 0 $"Directory %s has been successfully backuped to %s" "$1" "$backup_dir"
    fi
    
    return $res 
}

# input
#	$1: dir to 
#	$2: reg exp of file name to be searched in a format of grep util
# output: filename
# return: error code
function _find(){
    local dir=$1
    local name_pattern=$2
    local all_obects=''
    all_objects=`ls $dir`
    if [ $? -ne 0 ]; then
	echo ""
	return 1
    fi
    local objects=`echo "$all_objects" | grep -e "$name_pattern"`
    if [ -z "$objects" ]; then
	return 0
    fi
    for obj in "$objects"; do
	echo "$dir/$obj"
    done
    return 0
}

# input
#	$1: file to be backed up
# output: path to a backup copy of the file
# return: error code
function mybackup() {
    local filepath=$1
    local now=`date +%s`
    if [ ! -f "$1" ]; then
        _T 1 $"No file to backup: %s" "$filepath" >&2
        return 1
    fi
    local newpath="$filepath.$now"
    cp -a "$filepath" "$newpath"
    if [ $? -gt 0 ]; then
        _T 1 $"Failed to make a backup copy for %s" "$filepath" >&2
        return 2
    fi
    echo "$newpath"
    return 0
}


# input
#	$1: file to be backed up
# output: information about a backup process
# return: error code
function backup() {
    backup_file=`mybackup $1`
    res=$?
    if [ $res -eq 0 ]; then
	_T 0 $"File %s has been successfully backuped to %s" "$1" "$backup_file"
    fi
    
    return $res 
}


# input
#	$1: service
#	$2: action
#	$3: error_log - optional
#	$4: error message type - optional
# output: information about service trying to do action
# return: error code
function do_service_action(){
    local service=$1
    local action=$2
    local log_file=$3
    local error_msg_type=$4
    local msg_ok=""
    local msg_error=""
    case "$action" in 
	start)
	    msg_ok=$"Service %s has been started successfully"
	    msg_error=$"Service %s failed to start"
	    ;;
	stop)    
	    msg_ok=$"Service %s has been stopped successfully"
	    msg_error=$"Service %s failed to stop"
	    ;;
	restart)    
	    msg_ok=$"Service %s has been restarted successfully"
	    msg_error=$"Service %s failed to restart"
	    ;;
	reload)    
	    msg_ok=$"Service %s has been reloaded successfully"
	    msg_error=$"Service %s failed to reload"
	    ;;
	*)
	    ;;
    esac
    
    is_service_exist=`ls /etc/rc.d/init.d | grep -e "^$service$"`
    if [ -z "$is_service_exist" ]; then
	_T 0 $"No such system service: %s" "$service"
	return 1
    fi
    
    /sbin/service "$service" "$action" > /dev/null 2>&1
    res=$?

    #do not process the result code if action is unknown 
    if [ -z "$msg_ok" ]; then
	return $res
    fi    
    
    if [ -z "$error_msg_type" ]; then
	error_msg_type=2
    fi    
    
		    
    if [ $res -eq 0 ]; then    
	_T 0 "$msg_ok" "$service"
    else
	_T $error_msg_type "$msg_error" "$service"
	if [ "$log_file" ]; then
	    _T $error_msg_type $"See %s for details" "$log_file"
	fi
    fi
    return $res
}

function do_service_action_critically(){
    do_service_action "$1" "$2" "$3" "$4"
    if [ $? -ne 0 ]; then
	exit 1
    fi
}


# input: none
# output: base dn
# return: error code
function get_ldap_base_dn() {
    local mds_base_ini=/etc/mmc/plugins/base.ini
    if [ -f "$mds_base_ini" ]; then
        local dn=`grep '^baseDN' $mds_base_ini | sed 's/^.*[[:space:]]\+=[[:space:]]\+//'`
        if [ -z "$dn" ]; then
    	    _T 2 $"Failed to get a base DN for the %s database" "LDAP" >&2
    	    exit 1
    	    return 1
        fi
        echo "$dn"
        return 0
    fi
    _T 2 $"Failed to find base configuration file for %s %s" "RDS" "$mds_base_ini" >&2
    exit 2

}


# input: none
# output: ldap admin password
# return: error code
function get_ldap_admin_password() {
    local mds_base_ini=/etc/mmc/plugins/base.ini
    if [ -f "$mds_base_ini" ]; then
        local password=`grep '^password\W' $mds_base_ini | sed 's/^.*[[:space:]]\+=[[:space:]]\+//'`
        if [ -z "$password" ]; then
    	    _T 2 $"Failed to get administrator credentials for the %s database" "LDAP" >&2
    	    exit 1
        fi
        echo "$password"
        return 0
    fi
    _T 2 $"Failed to find base %s configuration file %s" "RDS" "$mds_base_ini" >&2
    exit 2
}



# input
#	$1: ldif schema file
#	$2: admin password - optional
# output: information about schema adding
# return: error code
function add_schema_ldif() {
    local ldap_config_dir=/etc/openldap/slapd.d
    local filename=${1##*/}
    local name=${filename%.*}
    local log_file=/var/log/ldap/ldap.log
    local password="$2"
    
    if [ ! -d "$ldap_config_dir" ]; then
	_T 1 $"%s configuration directory doesn't exist" "LDAP"
	return 1
    fi

    
    if [ ! -f "$1" ]; then
	_T 1 $"%s schema file doesn't exist" "$1"
	return 1
    fi
    
    if [ -z "$password" ]; then
	password=`get_ldap_admin_password`
	if [ $? -gt 0 ]; then
	    return 2
	fi
    fi
    
    ldap_schema=`_find $ldap_config_dir/cn=config/cn=schema $filename`
    if [ -f "$ldap_schema" ]; then
        _T 0 $"%s schema is already present in the %s database" "$name" "LDAP"
        return 0
    else
        ldapadd -x -D "cn=config" -w "$password" -H ldap://localhost:389 -f "$1" > /dev/null 2>&1 
        if [ $? -eq 0 ]; then 
    	    _T 0 $"%s schema has been added successfully to the %s database" "$name" "LDAP"
        else 
    	    _T 2 $"%s schema failed to add" "$name" 
	    _T 2 $"See %s for details" "$log_file"
    	    return 3
        fi
    fi
    return 0
}

# input: none
# output: name of temporary fil
# return: error code
function make_temp() {
    tmpfile=`mktemp ${TMP:-/tmp}/RSS.XXXXXXXXXXXX`
    if [ -f "$tmpfile" ]; then
	echo "$tmpfile"
	return 0
    fi
    _T 1 $"Failed to create a temporary file" >&2
    return 1
}

# input
#	$1: domain name
# output: ldap suffix for the domain name (e.g. for foo.bar domain the ldap suffix is dc=foo,dc=bar)
# return: error code
function calc_suffix() {
    old_ifs=${IFS}
    IFS="."
    for component in $1; do
	result="$result,dc=$component"
    done
    IFS="${old_ifs}"
    echo "${result#,}"
    return 0
}


# input
#	$1: LDAP database directory
# output: none
# return: none
function clean_ldap_database() {
    rm -f "$1"/{*.bdb,log.*,__*,alock}
}


# input
#	$1: text
# output: text adapted to sed utility: / becomes \/ ; & becomes \&  
# return: none
escape_sed() {
 echo $1 | \
 sed \
  -e 's/\//\\\//g' \
  -e 's/\&/\\\&/g'
}

# input
#	$1: schema path
# output: information about schema adding 
# return: none
function add_schema() {
    schema=`basename $1`
    # add schema in LDAP
    grep -q "$schema" /etc/openldap/schema/local.schema
    if [ $? -ne 0 ]; then
        echo "include /etc/openldap/schema/$schema" >> /etc/openldap/schema/local.schema
    fi
    cp -f "$1" /etc/openldap/schema/
    _T 0 $"Schema %s has been added successfully to the %s database" "$schema" "LDAP"
}



#MySQL functions

# mysql functions vars
config="/tmp/.my.cnf.$$"
command="/tmp/.mysql.$$"

function mysql_prepare() {
    touch $config $command
    chmod 600 $config $command
}

function mysql_do_query() {
    echo "$1" >$command
    #sed 's,^,> ,' < $command  # Debugging
    mysql --defaults-file=$config <$command
    return $?
}

# This simple escape works correctly in both places.
function mysql_basic_single_escape () {
    # The quoting on this sed command is a bit complex.  Single-quoted strings
    # don't allow *any* escape mechanism, so they cannot contain a single
    # quote.  The string sed gets (as argv[1]) is:  s/\(['\]\)/\\\1/g
    #
    # Inside a character class, \ and ' are not special, so the ['\] character
    # class is balanced and contains two characters.
    echo "$1" | sed 's/\(['"'"'\]\)/\\\1/g'
}

function mysql_make_config() {
    local rootpass="$1"
    echo "# mysql_secure_installation config file" >$config
    echo "[mysql]" >>$config
    echo "user=root" >>$config
    local esc_pass=`mysql_basic_single_escape "$rootpass"`
    echo "password='$esc_pass'" >>$config
    #sed 's,^,> ,' < $config  # Debugging
}

function mysql_check_root_password() {
    local rootpass=$1
    mysql_make_config "$rootpass"
    mysql_do_query "" 2>/dev/null
    return $?
}

function mysql_cleanup() {
    rm -f "$config" "$command"
}

