#!/bin/sh

. '../functions.sh'
set_locale_settings

rootpwd=$1
auditpwd=$2

# mysql setup
mysql_prepare
mysql_check_root_password "$rootpwd"
if [ $? -ne 0 ]; then
    _T 2 $"Typed %s %s password is not valid" "MySQL" "root"
    mysql_cleanup
    exit 1
fi

mysql_do_query "DROP DATABASE audit;" 2>/dev/null
mysql_do_query "CREATE DATABASE audit CHARACTER SET utf8 COLLATE utf8_general_ci;"

_T 0 $"%s database has been created" "Audit"

mysql_do_query "GRANT ALL PRIVILEGES ON audit.* TO 'audit'@'localhost' IDENTIFIED BY '$auditpwd' WITH GRANT OPTION; FLUSH PRIVILEGES;"
_T 0 $"%s database privileges have been granted" "Audit"

mysql_cleanup

# audit tables setup
audittpl="templates/base-audit.ini.tpl"

grep -q "^\[audit\]" /etc/mmc/plugins/base.ini
if [ $? -ne 0 ]; then
    # first audit install
    cat $audittpl >> /etc/mmc/plugins/base.ini
    sed -i "s/\@AUDITPASSWORD\@/${auditpwd}/" /etc/mmc/plugins/base.ini
else
    # audit reconfigure
    sed -i "s/^\(dbpassword[[:space:]]\+=[[:space:]]\+\).*$/\1${auditpwd}/" /etc/mmc/plugins/base.ini
fi

mmc-helper audit init 2>/dev/null

do_service_action_critically mmc-agent restart "/var/log/mmc/mmc-agent.log"

_T 8 $"%s module has been activated in the %s interface: %s" "Audit" "RDS" "http://@HOSTNAME@/mmc/"

exit 0
