#!/bin/bash
# (c) 2011 www.osinit.ru

. "../functions.sh"
set_locale_settings

ZONES_DIR=/var/named/named.ldap
TEMPLATES_DIR=templates
LDAPBINDFS_MOUNTPOINT=/var/named/ldap.mnt
NETWORK_INI=/etc/mmc/plugins/network.ini
BASE_INI=/etc/mmc/plugins/base.ini
DEFAULT_IFS=$IFS
LDAPMODIFY=/usr/bin/ldapmodify
LDAPMODRDN=/usr/bin/ldapmodrdn
LDAPADD=/usr/bin/ldapadd
DDNS_KEY_NAME=ddnskey
DDNS_KEY_PATH=/etc/ddns.key

#check whether zone file must be updated
#details: current state of file is defined by string containing `allow-update` substring
#	  if this substring exist in file, then file is considered as dynamic dns zone file
#return: 0 or 1
function is_need_to_update_zone_file(){
    local newddns=$1
    local file=$2
    local ddnsflag="allow-update"
    cat $file | grep $ddnsflag > /dev/null 2>&1
    if [ $? = "0" ]; then 
	local ddns=1 
    else
	local ddns=0
    fi
    if [ $ddns = $newddns ]; then
	return 0
    fi
    
    return 1
}

#replaced some of ldap url escapes characters by its hexademical values
#details: it is required by zone file of named
#return: url with replaced escape characters
function replace_ldap_url_escapes(){
    local url=$1
    local newurl=`echo $url|sed -e "\
		s:,:%2C:g;
		s: :%20:g;
		s:=:%3D:g"`
    echo "$newurl"
}

#get parameters needed for convertion
#return: ldapurl, dns reader, dns reader password values which split by whitespace or empty string
function get_file_convertion_parameters(){
    local newddns=$1
    if [ $newddns = 0 ]; then 
	local dnsdn=`cat $NETWORK_INI | awk 'begin {flag = 0 }; $0 ~ /\[dns\]/ {flag =1 }; {if (flag == 1) {print $0}} '| grep '^dn'| sed "s/^.*[[:space:]]\+=[[:space:]]\+//"`
	local ldapurl="ldap://127.0.0.1/$dnsdn"
	local basedn=`get_ldap_base_dn`
	local dnsreader="uid=LDAP Admin,ou=System Accounts,$basedn"
	local dnsreaderpassword=`get_ldap_admin_password`
	dnsreader=`replace_ldap_url_escapes "$dnsreader"`
	echo "$ldapurl $dnsreader $dnsreaderpassword"
    else
	echo ""
    fi
}

#convert zone file to new dns format
#details: parse zone file to extract zones, create a new zone file and replace an old zone file with a new one
function convert_zone_file(){
    local newddns=$1
    local file=$2
    local basezone=`basename $file`

    local convertedfile=`make_temp`

    #get zones of zonefile
    local str=`grep '^zone' $file`
    local zones=""
    local word
    for word in $str
    do
        local z=`expr match "$word" '"\(.*\)"'`
        zones="$zones $z"    
    done

    local zone
    for zone in $zones
    do
        if [ $newddns = 1 ]; then 
	    cat $TEMPLATES_DIR/ddnszone.tpl | sed -e "\
		s:@ZONE@:$zone:g;
		s:@ZONEFILE@:$LDAPBINDFS_MOUNTPOINT/$basezone/$zone:g;
		s:@ZONEJOURNAL@:$ZONES_DIR/$zone.jnl:g" >> $convertedfile
	    
	else
	    ldapurl=$3
	    dnsreader=$4
	    dnsreaderpassword=$5
	    dnsreaderpassword_e=`escape_sed $dnsreaderpassword`
	    cat $TEMPLATES_DIR/zone.tpl | sed -e "\
		s|@ZONE@|$zone|g;
		s|@LDAPURL@|$ldapurl|g;
		s|@DNSREADER@|$dnsreader|g;
		s|@DNSREADERPASSWORD@|$dnsreaderpassword_e|g" >> $convertedfile
	fi

    done
    mv -f $convertedfile $file 
}

#get subnet ddns statemets
#details: parse a subnet entry and extract dhcpStatements
#return: dchp statements in ldif format
function get_ddns_statements(){
    local entry=$1
    
    local rawstatements=`ldapsearch -x -LLL -b "$entry" "(objectClass=dhcpSubnet)" dhcpStatements`
    local statements=`echo $rawstatements | sed -e "\
					    s| dhcpStatements:\s\+|\n|g;
					    s|dn: $entry||g;
					    s|\n ||g;
					    s|  ||g"`

    local ddnsprefixes="key include ddns-domainname ddns-rev-domainname ddns-updates zone"
    local ddnsstatements=""	
    #echo "st: $rawstatements"
    #echo "0stbegin: $notddnsstatements"
    local lastifs=$IFS
    IFS=$'\n'
    local statement
    for statement in $statements
    do
        IFS=$DEFAULT_IFS
        #echo $statement
        statementprefix=`echo $statement | cut -d' ' -f1`
        for prefix in $ddnsprefixes 
        do
    	    if [ "$prefix" = "$statementprefix" ]; then
	        ddnsstatements="${ddnsstatements}dhcpStatements: ${statement}"$'\n'
	        break
	    fi
	done
	#echo ""
	IFS=$'\n'
    done
    IFS=$lastifs
    echo "$ddnsstatements"
}

#extract subnet name from a ldap subnet domain name
function get_subnet_name(){
    local dn=$1
    result=`expr match "$dn" '.*cn=\([0-9.]\+\).*'`
    echo $result
}

#delete subnet ddns statements from a dhcp subnet entry 
function delete_ddns_statements(){
    local entry=$1
    local ddnsstatements=$2
    local basedn=$3
    local password=$4
    local subnetname=`get_subnet_name "$entry"`
    
    local ddnsstatementsdeleteldif=`make_temp`
    #echo "$ddnsstatements"
    local tmp=`cat <<-TMP
		dn: $entry
		changetype: modify
		delete: dhcpStatements
		$ddnsstatements
		TMP`
    echo "$tmp" >> $ddnsstatementsdeleteldif
    local result=`$LDAPMODIFY -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -f $ddnsstatementsdeleteldif 2>&1`
    if [ $? -ne 0 ]; then
	_T 0 $"Failed to delete current dynamic %s settings from %s" DNS $subnetname
	echo "$result"
    else
	_T 0 $"Current dynamic %s settings has been deleted from %s" DNS $subnetname
    fi

    #cat $ddnsstatementsdeleteldif
    rm -f $ddnsstatementsdeleteldif
}

#parse the ddns key file and extract algorithm and secret fields
function get_ddns_key_attributes(){
    if [ -f "$DDNS_KEY_PATH" ]; then
	local keydata=`cat $DDNS_KEY_PATH`
	local algorithm=`expr match "$keydata" '.*algorithm \([a-zA-Z0-9.-]*\).*'` 
	local secret=`expr match "$keydata" '.*secret \"\(.*\)\".*'` 
	echo "$algorithm $secret"
    else
	echo ""
    fi
}

#get domain name of a subnet
#details: domain name of a subnet is link to dns zone
function get_subnet_domain_name(){
    local entry=$1
    local options=`ldapsearch -x -LLL -b "$entry" "(objectClass=dhcpSubnet)" dhcpOption`
    local o
    local lastifs=$IFS
    local IFS=$'\n'
    local dn=""
    for o in $options; do
	local result=`expr match "$o" '.*domain-name \"\(.*\)\".*'` 
	if [ $result ]; then
	    dn=$result
	    break
	fi
    done
    IFS=$lastifs
    echo "$dn"
}

#get reverse zone of a zone
#return: reverse zone or empty string if zone is no exist
function get_reverse_zone(){
    local zonedn=$1
    local basedn=$2
    local password=$3
    local zonesdata=`ldapsearch -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -LLL -s one -b "$zonedn" ou`
    local lastifs=$IFS
    local IFS=$'\n'
    local reversezone=""
    local e
    for e in $zonesdata; do
	local result=`expr match "$e" 'ou: \(.*.in-addr.arpa\).*'` 
	if [ $result ]; then
	    reversezone=$result
	    break
	fi
    done
    IFS=$lastifs
    echo "$reversezone"
}

#get zone name server
#details: name server is got from the SOA record of a dns zone 
function get_zone_nameserver(){
    local zonedn=$1
    local basedn=$2
    local password=$3
    local soadata=`ldapsearch -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -LLL -b "$zonedn" soaRecord`
    local lastifs=$IFS
    local ns=""
    IFS=$'\n'
    local e
    for e in $soadata; do
	local result=`expr match "$e" 'sOARecord: \([a-zA-Z0-9._-]*\). .*'`
	if [ $result ]; then
	    ns=$result
	    break
	fi
    done
    IFS=$lastifs
    echo "$ns"
}

#get potencial reverse zone
#details: extract ip, reflect it, cut a needed part, add in-addr.arpa suffix
function get_potencial_reversezone(){
    local subnetname=$1
    #local dhcpdata=`ldapsearch -x -LLL -b "$entry" "(objectClass=dhcpSubnet)" dhcpNetMask`

    local lastifs=$IFS
    
    IFS="."
    set -- $subnetname
    local reverseip=`expr match "$4.$3.$2.$1" "[0.]*\(.*\)"`
    
    IFS=$lastifs

    echo "$reverseip.in-addr.arpa"
}

#add dynamic dns statements to subnet
function add_ddns_statements(){
    local entry=$1
    local ddnskeyattributes=$2
    local basedn=$3
    local password=$4
    local dnsdn="ou=dns,$basedn"
    
    local oldifs=$IFS
    IFS=" "
    set -- $ddnskeyattributes
    local algorithm=$1
    local secret=$2
    IFS=$oldifs
    
    #echo "$algorithm"
    #echo "$secret"

    local subnetname=`get_subnet_name "$entry"`
    #echo "0Subnet analysis:# $subnetname ..."

    local subnetdn=`get_subnet_domain_name "$entry"`
    if [ -z $subnetdn ]; then
	_T 0 $"Failed to get the subnet domain name for %s" $subnetname
	_T 0 $"Dynamic %s settings have not been set" DNS
	return
    fi
    local zone="$subnetdn"
    #echo "$zone"

    local zonens=`get_zone_nameserver "ou=$zone,ou=$zone,$dnsdn" "$basedn" "$password"`
    if [ -z $zonens ]; then
	_T 0 $"Failed to get the zone nameserver of %s" $zone
	_T 0 $"Dynamic %s settings have not been set" DNS
	return
    fi
    #echo "$zonens"
    
    local reversezone=`get_reverse_zone "ou=$zone,$dnsdn" "$basedn" "$password"`
    local reversezonens=''
    if [ -z $reversezone ]; then
	_T 0 $"Failed to get the reverse zone of %s" $zone
	_T 0 $"Potencial reverse zone settings have been set"
	reversezone=`get_potencial_reversezone "$subnetname"`
	reversezonens=$zonens
	
	_T 0 $"Reverse zone: %s" $reversezone
	_T 0 $"Reverse zone name server: %s" $reversezonens
    else
	reversezonens=`get_zone_nameserver "ou=$reversezone,ou=$zone,$dnsdn" "$basedn" "$password"`
    fi
    #echo "$reversezone"
    #echo "$reversezonens"
    ddnsldif=`make_temp`
    cat $TEMPLATES_DIR/add-subnet-ddns-attr.ldif.tpl | sed -e "\
		s|@SUBNET_ENTRY@|$entry|g;
		s|@KEY_NAME@|$DDNS_KEY_NAME|g;
		s|@DDNS_DN@|$zone|g;
		s|@FORWARD_ZONE@|$zone|g;
		s|@FORWARD_ZONE_NS@|$zonens|g;
		s|@REVERSE_ZONE@|$reversezone|g;
		s|@REVERSE_ZONE_NS@|$reversezonens|g" >> $ddnsldif
    #cat $ddnsldif
    result=`$LDAPMODIFY -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -f $ddnsldif 2>&1`
    if [ $? -ne 0 ]; then
	_T 0 $"Failed to add dynamic %s settings to %s" DNS $subnetname
	echo "$result"
    else
	_T 0 $"Dynamic %s settings have been added to %s" DNS $subnetname
    fi
    rm -f $ddnsldif
}

#get entries including soa records
function get_ddnsed_soa_entries(){
    local basedn=$1
    local password=$2
    
    local rawsoadata=`ldapsearch -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -LLL -b "ou=dns,$basedn" "(soaRecord=*)" dn`
    local soaentries=`echo $rawsoadata | sed -e "\
						s|dn: |\n|g;
						s| \+||g" | grep -v "relativeDomainName=@" | grep -v "^$"`
    echo "$soaentries"
}

#rename entries including SOA record from FQDN to @
#details: it is need to do because otherwise named can't find soa and ns records in FQDNned entries stored in LDAP
function rename_soa_entry(){
    local soa=$1
    local basedn=$2
    local password=$3

    local tmp=`make_temp`
    echo -e "$soa\nrelativeDomainName=@" > $tmp
    $LDAPMODRDN -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -r -f "$tmp"
    rm -f $tmp
}

#extract entry with zone description
#details: ldapbindfs removes it in DDNS mode, but this entry is required when mmc shows zones in web.
function extract_description_entry(){
    local entry=$1
    local basedn=$2
    local password=$3
    
    local txt=`ldapsearch -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -LLL -b "$entry" txtRecord \
	               | grep "Record" \
	               | sed -e "s/tXTRecord:\s\+//g"`
	    	    	    
    if [ -z "$txt" ]; then
    	descriptionrecord=""
    else
	descriptionrecord=`echo "tXTRecord: $txt" | tr '\n' ' '`
    fi
	    
    local descriptionfile=`make_temp`
    cat $TEMPLATES_DIR/zone-description.ldif.tpl | sed -e "\
		s|@ZONE@|$zone|g;
		s|@BASE_ZONE_DN@|$basezonedn|g;
		s|@DESCRIPTION_RECORD@|$descriptionrecord|g" > $descriptionfile
		
    local result=`$LDAPADD -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -f $descriptionfile`
    #cat $descriptionfile
    rm -f $descriptionfile
    if [ -z "$result" ]; then
	_T 0 $"Failed to convert the zone description for %s" $zone
	return -1
    fi
    return 0
}

#delete TTL and TXT records from soa entry
#details: this entries, as a rule, are created by ldapbindfs in DDNS mode
function delete_soa_entry_ddns_attrs(){
    local entry=$1
    local zone=$2
    local basedn=$3
    local password=$4

    local ddnsdataldif=`make_temp`
    local tmp=`cat <<-TMP
		dn: $entry
		changetype: modify
		delete: tXTRecord
		-
		delete: dNSTTL
		TMP`
    echo "$tmp" >> $ddnsdataldif
    local result=`$LDAPMODIFY -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -f $ddnsdataldif`
    if [ -z "$result" ]; then
	_T 0 $"Failed to delete dynamic %s attributes of %s" DNS $zone
    fi
    rm -f $ddnsdataldif
}

#main function to convert network data
function convert_network_data(){
    local newddns=$1
    local basedn=$2
    local password=$3
    
    if [ $newddns = 1 ]; then 
	_T 0 $"Converting zone files to dynamic %s format..." DNS
    else
	_T 0 $"Converting zone files to %s format..." DNS
    fi
    
#: << 'COM1'
#: << 'COM1'

    #look through files of named zones dir and convert them if it is necessary
    fileconvertionparameters=`get_file_convertion_parameters $newddns`
    local file
    
    local isEmptyDir=`find $ZONES_DIR -type d -empty`
    if [ ! $isEmptyDir ]; then
    
	for file in $ZONES_DIR/*;
	do
	    local filename=`basename $file`
	    local extension=${filename##*.}

	    #skip named jnl files
	    if [ "$extension" = "jnl" ];then
		continue
	    fi

	    #check whether update is needed
	    is_need_to_update_zone_file $newddns $file
	    if [ $? = 0 ];then
		continue
	    fi
	
	    #convert zone file to new format	
	    convert_zone_file "$newddns" "$file" $fileconvertionparameters
	    chmod 640 $file
	    chown root:named $file
	    _T 0 $"Zone file has been converted: %s" $file
	done
    fi
     _T 0 $"Zone files converting has been finished"
#COM1

    local dhcpdn="ou=dhcp,$basedn"

    #get key algorithm and secret    
    local ddnskeyattributes=''
    if [ $newddns = 1 ]; then
	ddnskeyattributes=`get_ddns_key_attributes`
	if [ -z "$ddnskeyattributes" ]; then
	    _T 2 "Failed to get attributes for dynamic %s key" DNS
	    _T 2 "Dynamic %s attributes have not been set" DNS
	    return
	fi
    fi

    if [ $newddns = 1 ]; then 
	_T 0 $"Converting subnets to dynamic %s format..." DNS
    else
	_T 0 $"Converting subnets to %s format..." DNS
    fi
    
    #get names of subnet entries
    local subnetentries=`ldapsearch -x -LLL -b "cn=DHCP Config,$dhcpdn" "(objectClass=dhcpSubnet)" dn | sed -e "s|dn:\s\+||g"`

    IFS=$'\n'
    local entry
    for entry in $subnetentries
    do
	local subnetname=`get_subnet_name "$entry"`

	#get dynamic dns statements for subnet 
        local ddnsstatements=`get_ddns_statements "$entry"`
        
        #delete existing dynamic dns statements 
        if [ "$ddnsstatements" ]; then
    	    delete_ddns_statements "$entry" "$ddnsstatements" "$basedn" "$password"
        fi
        
        #add dynamic dns statements to subnet entry if dynamic dns mode is set
        if [ $newddns = 1 ]; then
    	    add_ddns_statements "$entry" "$ddnskeyattributes" "$basedn" "$password"
        fi
        
        _T 0 $"Subnet has been converted: %s" $subnetname

	#echo "$ddnsstatements"
    done
    _T 0 $"Subnets converting has been finished"
#COM1
    if [ $newddns = 0 ]; then
	_T 0 $"Converting %s entries to %s format..." DNS DNS
	local soaentries=`get_ddnsed_soa_entries "$basedn" "$password"`
	#echo "$soa_entries"
	local entry
	for entry in $soaentries; 
	do
	    rename_soa_entry "$entry" "$basedn" "$password" 
	    
	    local zone=`expr match "$entry" "relativeDomainName=[a-zA-Z0-9.-]*,ou=\([a-zA-Z0-9.-]*\)"`
	    local basezonedn=`expr match "$entry" ".*\(ou=[a-zA-Z0-9.-]*,ou=[a-zA-Z]*,.*\)"`
	    local descriptionentry=`ldapsearch -x -w "$password" -D "uid=LDAP Admin,ou=System Accounts,$basedn" -LLL -b "zonename=$zone,ou=$zone,$basezonedn" dn`

	    if [ "$descriptionentry" ]; then
		continue
	    fi

	    extract_description_entry "$entry" "$basedn" "$password"
	    if [ $? -ne 0 ]; then
		continue
	    fi 
	    
	    delete_soa_entry_ddns_attrs "$entry" "$zone" "$basedn" "$password"
	done
	_T 0 $"%s entries converting has been finished" DNS
    fi

    IFS=$DEFAULT_IFS

}


function convert_network_data_to_ddns_format(){
    convert_network_data 1 $1 $2
}

function convert_network_data_from_ddns_format(){
    convert_network_data 0 $1 $2
}