#!/bin/bash
# (c) 2011 www.osinit.ru
TEMPLATES=templates
MMCINIDIR=/etc/mmc/plugins
DNSCONFDIR=/var/lib/named
ZONESDIR=/var/named/named.ldap

if [ "`id -u`" != "0" ]; then
	echo "2Error, must be root user"
	exit 1
fi

. '../functions.sh'

if [ ! -h /var/lib/named ]; then
    ln -s /var/named /var/lib/named > /dev/null 2>&1
fi
    

#templates
ldapbindfs_run_template=$TEMPLATES/ldapbindfs.tpl
ldapbindfs_conf_template=$TEMPLATES/ldapbindfs.conf.tpl
ddns_key_template=$TEMPLATES/ddns.key.tpl
network_ini_template=$TEMPLATES/network.ini.tpl

named_pid=/var/lib/named/var/run/named.pid
dhcpd_pid=/var/run/dhcpd/dhcpd.pid
dhcpd_leases=/var/lib/dhcp/dhcpd.leases


#mmc-wizard ini file
mds_conig="/var/lib/mmc-wizard/mds_config.ini"

#mmc network plugin ini file
network_ini=$MMCINIDIR/network.ini

SLAPTEST="/usr/sbin/slaptest"

slapd_conf=/etc/openldap/slapd.conf



#parameters 
mds_base_ini="$MMCINIDIR/base.ini"

if [ ! -f $mds_base_ini ]; then
    echo "2MMC interface is not installed"
    echo "2Aborting"
    exit 1
fi

if [ ! -f $network_ini ]; then
    echo "2Network module is not installed"
    echo "2Aborting"
    exit 1
fi


#LDAP suffix            
suffix=`grep '^baseDN' $mds_base_ini | sed 's/^.*[[:space:]]\+=[[:space:]]\+//'`

if [ "x$suffix" = "x" ];then
    echo "2RDS domain is empty"
    echo "2Aborting"
    exit 1
fi  

#LDAP administrator's password
adminpass=`grep '^password\W' $mds_base_ini | sed 's/^.*[[:space:]]\+=[[:space:]]\+//'`
if [ "x$adminpass" = "x" ];then
    echo "2LDAP Admin password is empty"
    echo "2Aborting"
    exit 1
fi  

#DNS base dn
dnsbasedn=`cat $network_ini | awk 'begin {flag = 0 }; $0 ~ /\[dns\]/ {flag =1 }; {if (flag == 1) {print $0}} '| grep '^dn'| sed "s/^.*[[:space:]]\+=[[:space:]]\+//"`
if [ "x$dnsbasedn" = "x" ];then
    echo "2DNS base dn is empty"
    echo "2Aborting"
    exit 1
fi    

#ddns is passed as $1
if [ "x$1" = "xon" ];then
    ddns=1
else
    ddns=0
fi

#mountpoint for ldapbindfs

#mountpoint=$DNSCONFDIR/ldap.mnt
mountpoint=/var/named/ldap.mnt

#mountpoint="$1"
if [ "x$mountpoint" = "x" ];then
    echo "2Mount point is empty"
    echo "2Aborting"
    exit 1
fi    

#dnsmod overlay configuration

#LDAP configuration
# add overlay loaading to slapd.conf

res=`cat $slapd_conf|grep "moduleload[[:space:]]*dnsmod.so"`
if [ -z "$res" ]; then
    oldddns=0
else
    oldddns=1
fi


if [ $ddns -ne $oldddns ]; then 

    echo "0Configure# slapd.conf..."
    backup $slapd_conf

    myslapdconf=`make_temp`
    
    if [ $ddns = 1 ]; then
	tmp=`make_temp`
	
	res=`cat $slapd_conf|grep "moduleload[[:space:]]*ppolicy.la"`
	if [ "x$res" = "x" ]; then 
    	    cat $slapd_conf|sed -e "\/argsfile[ \t]*\/var\/run\/ldap\/slapd.args/a moduleload dnsmod.so">$tmp
	else
    	    cat $slapd_conf|sed -e "\/moduleload[ \t]*ppolicy.la/a moduleload\tdnsmod.so">$tmp
	fi

	tac $tmp|sed "0,/^index/s/^index/dnsmod_dnsbase $dnsbasedn~dnsmod_zonedir \/var\/named\/ldap.mnt~dnsmod_lock \/var\/lock\/subsys\/dnsmod~overlay dnsmod~~index/"|tr '~' '\n'|tac>$myslapdconf
    else
	cat $slapd_conf | sed "/dnsmod/d" > $myslapdconf
    fi
    
    chmod 0640 $myslapdconf
    chgrp ldap $myslapdconf

    #test openldap configuration

    $SLAPTEST -u -f $myslapdconf > /dev/null 2>&1
    if [ $? -ne 0 ]; then
	echo "2OpenLDAP configuration file was generated with errors."
        echo "2Aborting. File used was# $myslapdconf"
	exit 1
    else
	echo "0OpenLDAP configuration file successfully generated."
    fi
    
    #stop ldap and mmc-agent
    /sbin/service ldap stop > /dev/null 2>&1
    if [ $? -eq 0 ]; then 
	echo "0Service ldap stopped successfully."
    else 
	echo "2Service ldap fails stopping. Check# /var/log/syslog"; exit 1
    fi

    /sbin/service mmc-agent stop > /dev/null 2>&1
    if [ $? -eq 0 ]; then 
	echo "0Service mmc-agent stopped successfully."
    else 
	echo "2Service mmc-agent fails stopping. Check# /var/log/mmc/mmc-agent"; exit 1
    fi
                                                                                                                                                            
#    backup_slapd_conf=`mybackup /etc/openldap/slapd.conf`
    echo "0Writing# /etc/openldap/slapd.conf..."
    cat $myslapdconf > /etc/openldap/slapd.conf; rm -f $myslapdconf; rm -f $tmp
    
    #start ldap
    /sbin/service ldap start > /dev/null 2>&1
    if [ $? -eq 0 ]; then 
	echo "0Service ldap started successfully."
    else 
	echo "2Service ldap fails starting. Check# /var/log/syslog" 
        exit 1
    fi
fi    

#generate configuration file for ldapbindfs

ADMIN="uid=LDAP Admin,ou=System Accounts,"

ldapbindfsconf=`make_temp`

cat $ldapbindfs_conf_template | sed -e "\
s:@BINDDN@:$ADMIN$suffix:g;
s:@PASS@:$adminpass:g;
s:@SUFFIX@:$suffix:g;
s:@DNSBASEDN@:$dnsbasedn:g"> $ldapbindfsconf

cat $ldapbindfsconf > /etc/ldapbindfs.conf; rm -f $ldapbindfsconf
    
#generate startup script for ldapbindfs

if [ -f /usr/sbin/ldapbindfs ]; then
    prefix=/usr/sbin
else
    if [ -f /usr/local/sbin/ldapbindfs ]; then
        prefix=/usr/local/sbin
    else
        echo "2ldapbindfs not found"; exit 1
    fi    
fi

ldapbindfsrun=`make_temp`

#echo $prefix

cat $ldapbindfs_run_template | sed -e "\
s:@PREFIX@:$prefix:g;
s:@LDAPDAEMON@:ldap:g;
s:@MOUNTPOINT@:$mountpoint:g"> $ldapbindfsrun

#cat $ldapbindfsrun > $MMCINIDIR/ldapbindfs.run; rm -f $ldapbindfsrun
cat $ldapbindfsrun > /etc/init.d/ldapbindfs; rm -f $ldapbindfsrun

chmod 0744 /etc/init.d/ldapbindfs
chown root:root /etc/init.d/ldapbindfs

/sbin/service ldapbindfs start > /dev/null 2>&1
if [ $? -eq 0 ]; then 
    echo "0Service ldapbindfs started successfully."
else 
    echo "2Service ldapbindfs fails starting. Check# /var/log/user.log"; exit 1
fi

#DNS
#namedconftmp=`make_temp`
namedconftmp=`make_temp`
tmp=`make_temp`

#stop named
/sbin/service named stop > /dev/null 2>&1
if [ $? -eq 0 ]; then 
    echo "0Service named stopped successfully."
else 
    echo "2Service named fails stopping. Check# /var/log/syslog"; exit 1
fi

#generate key
keyfile=`dnssec-keygen -a hmac-md5 -b 128 -n USER ddnskey`

key=`cat $keyfile.private | grep Key| sed "s/Key: //g"`

cat $ddns_key_template | sed -e "s:@KEY@:$key:g"> $DNSCONFDIR/etc/ddns.key

#make a link to ddns key file
if [ ! -f /etc/ddns.key ]; then
    ln -s /var/lib/named/etc/ddns.key /etc/ddns.key
fi    

rm $keyfile.private
rm $keyfile.key


echo "0Configure# /etc/named.conf..."

cat /etc/named.conf > $namedconftmp

res=`cat $namedconftmp|grep include[[:space:]]*\"/etc/ddns.key\"`

if [ "x$res" = "x" ]; then 
    cat $namedconftmp|sed "\/include[ \t]*\"\/etc\/rndc.key\"/a include \"\/etc\/ddns.key\";">$tmp
else
    cat $namedconftmp>$tmp
fi    

cat $tmp|sed "s/allow-update {.*}/allow-update { key ddnskey; }/">$namedconftmp

backup_named_conf=`mybackup $DNSCONFDIR/etc/named.conf`

cat $namedconftmp > /etc/named.conf; 
if [ $? -eq 0 ]; then 
    echo "0named.conf ok"
else 
    echo "2named.conf error" 
    exit 1
fi

rm -f $namedconftmp
rm -f $tmp

#need to change owner for named.ldap dir
owner=root                                                
if [ $ddns = 1 ]; then
    owner=named
fi
chown $owner:named $ZONESDIR > /dev/null 2>&1
if [ "$?" = "0" ]; then
    echo "0Zones directory owner changed successfully"
else
    echo "1Can't change owner of# $ZONESDIR"
fi

chmod 755 $ZONESDIR

#need to change access rights for rndc.conf for ldap overlay
chmod 666 $DNSCONFDIR/etc/rndc.conf

#convert network data to new format
#it is run in subshell in order to save values of variables
(
. ddns-data-convertor.sh
if [ $ddns = 1 ]; then
    convert_network_data_to_ddns_format $suffix $adminpass
else
    convert_network_data_from_ddns_format $suffix $adminpass
fi
)

if [ $ddns = 1 ]; then
    ddns_disable=0
else
    ddns_disable=1
fi

backup /etc/mmc/plugins/network.ini > /dev/null 2>&1
cat $network_ini_template | sed -e "\
s:@SUFFIX@:$suffix:g;
s:@DHCPD_PID@:$dhcpd_pid:g;
s:@DHCPD_LEASES@:$dhcpd_leases:g;
s:@NAMED_PID@:$named_pid:g;
s:@DDNS_DISABLE@:$ddns_disable:g;" > /etc/mmc/plugins/network.ini



# remove old jnl files if they are exist
for file in $ZONESDIR/*;
do
    filename=`basename $file`
    extension=${filename##*.}
    if [[ "$extension" = "jnl" && $ddns = 1 ]];
    then
        rm -f $file
    fi                    
done
                
# dhcp restart
/sbin/service dhcpd restart > /dev/null 2>&1
if [ $? -eq 0 ]; then 
    echo "0Service dhcpd restarted successfully."
else 
    res=`cat /var/log/dhcp-ldap-startup.log | grep "subnet[[:space:]]"`
    if [ -z "$res" ]; then
	echo "1Service dhcpd fails restarting. Check# /var/log/syslog"
	echo "1Make sure that you have a created DHCP subnet"
	echo "1You can see the list of subnets and create a new one with help of MMC#: http://@HOSTNAME@/mmc/"
    else
    	echo "1Service dhcpd fails restarting. Check# /var/log/syslog"
    fi
fi

# dns restart
/sbin/service named restart > /dev/null 2>&1
if [ $? -eq 0 ]; then 
    echo "0Service named restarted successfully."
else 
    echo "2Service named fails restarting. Check# /var/log/syslog"
    exit 1
fi

/sbin/service mmc-agent start > /dev/null 2>&1
if [ $? -eq 0 ]; then 
    echo "0Service mmc-agent started successfully."
else 
    echo "2Service mmc-agent fails starting. Check# /var/log/mmc/mmc-agent"
    exit 1
fi

#ldap run priority changes on level before named cause run order should be: ldap[need to set 11] -> ldapbindfs[12] (get data from ldap and convert it to zone files) -> named[13] (read zone files)
if [ $ddns = 1 ]; then
    chkconfig ldapbindfs on
    ldap_priority=12
else
    chkconfig ldapbindfs off
    ldap_priority=27
fi

ldap_run_tmp=`mybackup /etc/rc.d/init.d/ldap`
old_line=`cat /etc/rc.d/init.d/ldap | grep '^# chkconfig' -m 1`
new_line=`echo $old_line | sed -r "s/(^.*:) (.*) (.*) (.*)/\1 \2 $ldap_priority \4/"`
cat $ldap_run_tmp | sed -e "s/$old_line/$new_line/"
echo $?

chkconfig slapd on

echo "8Dynamic DNS configuration done"
