#!/bin/bash
# (c) 2011 www.osinit.ru
TEMPLATES=templates
MMCINIDIR=/etc/mmc/plugins
DNSCONFDIR=/var/lib/named
ZONESDIR=/var/named/named.ldap
LDAPCONFIGDIR=/etc/openldap/slapd.d

if [ "`id -u`" != "0" ]; then
	echo "2Error, must be root user"
	exit 1
fi

. '../functions.sh'

set_locale_settings

if [ ! -h /var/lib/named ]; then
    ln -s /var/named /var/lib/named > /dev/null 2>&1
fi
chmod 755 /var/named

#templates
ldapbindfs_run_template=$TEMPLATES/ldapbindfs.tpl
ldapbindfs_conf_template=$TEMPLATES/ldapbindfs.conf.tpl
ddns_key_template=$TEMPLATES/ddns.key.tpl
network_ini_template=$TEMPLATES/network.ini.tpl
dnsmod_add_ldif_template=$TEMPLATES/dnsmod-add.ldif.tpl
dnsmod_config_ldif_template=$TEMPLATES/dnsmod-config.ldif.tpl

named_pid=/var/run/named/named.pid
dhcpd_pid=/var/run/dhcpd.pid
dhcpd_leases=/var/lib/dhcpd/dhcpd.leases


#mmc network plugin ini file
network_ini=$MMCINIDIR/network.ini
mds_base_ini=$MMCINIDIR/base.ini

if [ ! -f $network_ini ]; then
    _T 2 $"Network module is not installed"
    exit 1
fi

suffix=`get_ldap_base_dn`
adminpass=`get_ldap_admin_password`
adminpass_e=`escape_sed $adminpass`

#DNS base dn
dnsbasedn=`cat $network_ini | awk 'begin {flag = 0 }; $0 ~ /\[dns\]/ {flag =1 }; {if (flag == 1) {print $0}} '| grep '^dn'| sed "s/^.*[[:space:]]\+=[[:space:]]\+//"`
if [ -z "$dnsbasedn" ]; then
    _T 2 $"Failed to get %s entry for %s" LDAP DNS
    exit 1
fi    

#ddns is passed as $1
if [ "x$1" = "xon" ];then
    ddns=1
else
    ddns=0
fi

#mountpoint for ldapbindfs
mountpoint=/var/named/ldap.mnt

#dnsmod overlay configuration
#LDAP configuration
#dnsmod overlay config
dnsmodconf=`make_temp`
bdb_dir_path=`_find $LDAPCONFIGDIR/cn=config bdb$`
if [ -z "$bdb_dir_path" ]; then
    bdb="olcDatabase={2}bdb"
else
    bdb=`basename $bdb_dir_path`
fi

cat $dnsmod_config_ldif_template | sed -e "\
s!@BDBDATABASE@!$bdb!g;
s!@SUFFIX@!$suffix!g"> $dnsmodconf

#cat $dnsmodconf
#exit

#add overlay loading
res=`ldapsearch -x -D "cn=config" -w $adminpass -b "cn=config" "(cn=module{0})" olcModuleLoad | grep dnsmod.so`
if [ -z "$res" ]; then
    oldddns=0
else
    oldddns=1
fi

if [ $ddns -ne $oldddns ]; then 
    if [ $ddns = 1 ]; then
        ldapmodify -x -D "cn=config" -w $adminpass -H ldap://localhost:389 -f $dnsmod_add_ldif_template > /dev/null
        if [ $? -eq 0 ]; then 
            _T 0 $"%s overlay has been added" dnsmod
        else 
            _T 2 $"Failed to add %s overlay" dnsmod
            _T 2 $"See %s for details" /var/log/ldap/ldap.log
            exit 1
        fi
        ldapadd -x -D "cn=config" -w $adminpass -H ldap://localhost:389 -f $dnsmodconf > /dev/null
        res=$?
	rm -f $dnsmodconf
        if [ $res -eq 0 ]; then 
            _T 0 $"%s overlay has been configured" dnsmod
        else 
            _T 2 $"Failed to configure %s overlay" dnsmod
            _T 2 $"See %s for details" /var/log/ldap/ldap.log
            exit 1
        fi
    fi
    #if ddns = 0
    #we can't delete dnsmod module from cn=module{0},cn=config dynamically: current ldap doesn't support such ability
    #if it is very required, then it would be done via <openldap dir>/slapd.d/cn=config/cn=module{0} modifying 
fi    



#looking for ldapbindfs
if [ -f /usr/sbin/ldapbindfs ]; then
    prefix=/usr/sbin
else
    if [ -f /usr/local/sbin/ldapbindfs ]; then
        prefix=/usr/local/sbin
    else
        _T 2 $"Failed to find %s service" ldapbindfs
        exit 1
    fi    
fi


#generate configuration file for ldapbindfs
admindn="uid=LDAP Admin,ou=System Accounts,$suffix"

ldapbindfsconf=`make_temp`

cat $ldapbindfs_conf_template | sed -e "\
s:@BINDDN@:$admindn:g;
s:@PASS@:$adminpass_e:g;
s:@SUFFIX@:$suffix:g;
s:@DNSBASEDN@:$dnsbasedn:g"> $ldapbindfsconf

cat $ldapbindfsconf > /etc/ldapbindfs.conf; rm -f $ldapbindfsconf

chmod 0600 /etc/ldapbindfs.conf
chown root:root /etc/ldapbindfs.conf

_T 0 $"%s has been configured" ldapbindfs


#generate startup script for ldapbindfs

ldapbindfsrun=`make_temp`

#echo $prefix

cat $ldapbindfs_run_template | sed -e "\
s:@PREFIX@:$prefix:g;
s:@LDAPDAEMON@:slapd:g;
s:@MOUNTPOINT@:$mountpoint:g" > $ldapbindfsrun

cat $ldapbindfsrun > /etc/init.d/ldapbindfs; rm -f $ldapbindfsrun

chmod 0744 /etc/init.d/ldapbindfs
chown root:root /etc/init.d/ldapbindfs

_T 0 $"%s startup script has been generated" ldapbindfs

do_service_action_critically ldapbindfs start /var/log/messages
do_service_action_critically named stop /var/log/messages


#generate key
keyfile=`dnssec-keygen -a hmac-md5 -b 128 -n USER -r /dev/urandom ddnskey`

key=`cat $keyfile.private | grep Key| sed "s/Key: //g"`

mkdir -p $DNSCONFDIR/etc
cat $ddns_key_template | sed -e "s:@KEY@:$key:g"> $DNSCONFDIR/etc/ddns.key

#make a link to ddns key file
if [ ! -f /etc/ddns.key ]; then
    ln -s /var/lib/named/etc/ddns.key /etc/ddns.key
fi    

rm -f $keyfile.private
rm -f $keyfile.key

_T 0 $"Dynamic %s key file has been generated" DNS

#DNS
namedconftmp=`make_temp`
tmp=`make_temp`

cat /etc/named.conf > $namedconftmp

res=`cat $namedconftmp|grep include[[:space:]]*\"/etc/ddns.key\"`

if [ "x$res" = "x" ]; then 
    cat $namedconftmp|sed "\/include[ \t]*\"\/etc\/rndc.key\"/a include \"\/etc\/ddns.key\";">$tmp
else
    cat $namedconftmp>$tmp
fi    

cat $tmp|sed "s/allow-update {.*}/allow-update { key ddnskey; }/">$namedconftmp

backup_named_conf=`mybackup /etc/named.conf`

cat $namedconftmp > /etc/named.conf

rm -f $namedconftmp
rm -f $tmp

_T 0 $"%s configuration file has been updated: %s" DNS /etc/named.conf

#need to change owner for named.ldap dir
owner=root                                                
if [ $ddns = 1 ]; then
    owner=named
fi

chown $owner:named $ZONESDIR > /dev/null 2>&1

chmod 755 $ZONESDIR

#no need to have rndc.conf file: rndc key generates via `rndc-confgen -a` by default
#need to change access rights for rndc.conf

chmod +r /etc/rndc.key

#convert network data to new format
#it is run in subshell in order to save values of variables
(
. ddns-data-convertor.sh
if [ $ddns = 1 ]; then
    convert_network_data_to_ddns_format $suffix $adminpass
else
    convert_network_data_from_ddns_format $suffix $adminpass
fi
)

# remove old jnl files if they are exist
for file in $ZONESDIR/*;
do
    filename=`basename $file`
    extension=${filename##*.}
    if [[ "$extension" = "jnl" && $ddns = 1 ]];
    then
        rm -f $file
    fi                    
done

if [ $ddns = 1 ]; then
    ddns_disable=0
else
    ddns_disable=1
fi

backup /etc/mmc/plugins/network.ini > /dev/null 2>&1
cat $network_ini_template | sed -e "\
s:@SUFFIX@:$suffix:g;
s:@DHCPD_PID@:$dhcpd_pid:g;
s:@DHCPD_LEASES@:$dhcpd_leases:g;
s:@NAMED_PID@:$named_pid:g;
s:@DDNS_DISABLE@:$ddns_disable:g;" > /etc/mmc/plugins/network.ini

_T 0 $"%s has been configured" RDS


#ldap run priority changes on level before named cause run order should be: ldap[need to set 11] -> ldapbindfs[12] (get data from ldap and convert it to zone files) -> named[13] (read zone files)
if [ $ddns = 1 ]; then
    ldap_priority=12
    chkconfig ldapbindfs on
else
    ldap_priority=27
    chkconfig ldapbindfs off
fi
slapd_run_tmp=`mybackup /etc/rc.d/init.d/slapd`
old_line=`cat /etc/rc.d/init.d/slapd | grep '^# chkconfig' -m 1`
new_line=`echo $old_line | sed -r "s/(^.*:) (.*) (.*) (.*)/\1 \2 $ldap_priority \4/"`
cat $slapd_run_tmp | sed -e "s/$old_line/$new_line/" > /etc/rc.d/init.d/slapd

_T 0 $"%s startup priority has been updated" LDAP


# dhcp restart
do_service_action dhcpd restart /var/log/messages 1
if [ $? -ne 0 ]; then 
    res=`cat /var/log/dhcp-ldap-startup.log | grep "subnet[[:space:]]"`
    if [ -z "$res" ]; then
	_T 1 $"Make sure that you have a created %s subnet" DHCP
	_T 1 $"You can see the list of subnets and create a new one with help of %s: %s" MMC http://@HOSTNAME@/mmc/
    fi
fi

do_service_action_critically ldapbindfs restart /var/log/messages
do_service_action_critically named restart /var/log/messages
do_service_action_critically mmc-agent restart /var/log/mmc/mmc-agent

chkconfig slapd on
_T 8 $"Dynamic %s has been configured" DNS
