#!/bin/bash
# Copyright Mandriva 2009, 2010 all rights reserved
if [ "`id -u`" != "0" ]; then
	echo "Error, must be root user"
	exit 1
fi

. '../functions.sh'

set_locale_settings
oldifs=$IFS ; IFS=$'\n' ; os_info=(`../os_info.sh`) ; IFS=$oldifs 
dist=${os_info[2]}


mds_network_template="templates/network.ini.tpl"
bind_template="templates/named.conf.tpl"

mds_base_ini="/etc/mmc/plugins/base.ini"

initnamed="/etc/init.d/named"


if [ "$dist" == "CentOS" ] || [ "$dist" == "ROSA Enterprise Linux Server" ] ; then
    bind_conf="/etc/named.conf"
    named_pid="/var/run/named/named.pid"
    dhcpd_pid="/var/run/dhcpd.pid"
    dhcpd_leases="/var/lib/dhcpd/dhcpd.leases"
    

    acl_file="/etc/mss_acls.conf"
    forward_file="/etc/mss_forwarders.conf"
    touch /var/named/dynamic/managed-keys.bind
    log_file=/var/log/messages
    
else
    bind_conf="/var/lib/named/etc/named.conf"
    named_pid="/var/lib/named/var/run/named.pid"
    dhcpd_pid="/var/run/dhcpd/dhcpd.pid"
    acl_file="/var/lib/named/etc/mss_acls.conf"
    forward_file="/var/lib/named/etc/mss_forwarders.conf"
    dhcpd_leases="/var/lib/dhcp/dhcpd.leases"
    log_file=/var/log/syslog

    ln -sf /var/lib/named/var/named/ /var/named
fi

mdssuffix=`get_ldap_base_dn`

networks="$1"
forwarders="$2"

backup /etc/rndc.key 2>/dev/null
rndc-confgen -r /dev/urandom -a -k "mykey" -u named > /dev/null 2>&1
if [ $? -eq 0 ]; then 
    _T 0 $"%s key has been generated successfully" rndc
else 
    _T 2 $"Failed to generate %s key" rndc
    exit 1
fi


backup /etc/mmc/plugins/network.ini
cat $mds_network_template > /etc/mmc/plugins/network.ini
sed -i "s/\@SUFFIX\@/$mdssuffix/" /etc/mmc/plugins/network.ini
sed -i "s|\@NAMED_PID\@|$named_pid|" /etc/mmc/plugins/network.ini
sed -i "s|\@DHCPD_PID\@|$dhcpd_pid|" /etc/mmc/plugins/network.ini
sed -i "s|\@DHCPD_LEASES\@|$dhcpd_leases|" /etc/mmc/plugins/network.ini

_T 0 $"%s has been configured" RDS

# create acl file
echo 'acl "mss" {' > $acl_file
echo "127.0.0.1/32;" >> $acl_file
if [ -z "$networks" ]; then
    _T 1 $"No networks are authorized to make external queries"
else
    for network in $networks
    do
        echo "$network;" >> $acl_file
    done
fi
echo "};" >> $acl_file

# create forward file
touch $forward_file
if [ "$forwarders" ]; then
    # fill forwarders file
    echo "forwarders {" > $forward_file
    for forwarder in $forwarders
    do
        echo "$forwarder;" >> $forward_file
    done
    echo "};" >> $forward_file
else
    # empty forwarders file
    echo "" > $forward_file
fi

backup $bind_conf
cat $bind_template > $bind_conf
sed -i "s|\@NAMED_PID\@|$named_pid|" $bind_conf

_T 0 $"%s server has been configured" DNS


touch /etc/logging.conf

do_service_action_critically mmc-agent restart /var/log/mmc/mmc-agent.log
do_service_action_critically named restart $log_file

sed -i 's/^# chkconfig.*$/# chkconfig - 30 70/g' $initnamed
chkconfig named on

_T 8 $"%s module has been activated in the %s interface" DNS RDS

if [ "$forwarders" ]; then
     _T 7 $"Your %s server will forward external queries to: %s" DNS "$forwarders"
fi

if [ "$networks" ]; then
    _T 7 $"Following networks are able to query your %s for external domains: %s" DNS  "$networks"
fi
_T 7 $"You can handle your %s zones from the %s interface: %s" DNS RDS http://@HOSTNAME@/mmc/
_T 8 $"Make sure you have enabled the %s service (port 53) on your firewall" DNS

exit 0
