#!/bin/bash
# (c) 2011 www.osinit.ru

ldap_config_dir="/etc/openldap/slapd.d"

if [ "`id -u`" != "0" ]; then
	echo "Error, must be root user"
	exit 1
fi

. '../../functions.sh'
set_locale_settings
check_host_fqdn
                                                                                                                                                            
function generate_password() {
    pass=`date|md5sum|head -c 16`
    if [ $? -ne 0 ]; then
	_T 2 "Failed to generate password" >&2
	exit 1
    fi
    echo "$pass"
}

function replace_placeholders() {
    cat $1 | sed -e "\
    s/@SUFFIX@/$suffix/g;\
    s/@KADMINPASSWD@/$kadmin_passwd/g;\
    s/@KDCPASSWD@/$kdc_passwd/g;\
    s/@SUFFIX@/$suffix/g;\
    s/@REALM@/$realm/g;\
    s/@DNSDOMAIN@/$dnsdomain/g;\
    s/@HOST@/$kdchostname/g;\
    s/@KDC_PORT@/$kdcport/g;\
    s/@KADMIN_PORT@/$kadminport/g;\
    s/@KPASSWD_PORT@/$KPASSWDPORT/g"> $2
}

function replace_dns_placeholders() {
    cat $1 | sed -e "\
    s/@SUFFIX@/$suffix/g;\
    s/@REALM@/$realm/g;\
    s/@DNSDOMAIN@/$dnsdomain/g;\
    s/@HOST@/$kdchostname/g;\
    s/@KDC_PORT@/$kdcport/g;\
    s/@KADMIN_PORT@/$kadminport/g;\
    s/@KPASSWD_PORT@/$KPASSWDPORT/g"> $2
}

function clear() {
    echo ""
}

#kerberos schema for LDAP 
kerberos_schema="templates/kerberos.schema"

#LDAP records for kerberos kdc and kadmin
data_template="templates/data.ldif.tpl"

#DNS data for kerberos - SRV and TXT records
#for adding
dns_data_template="templates/dns-data.ldif.tpl"
#for modifying
dns_data_modify_template="templates/dns-data-modify.ldif.tpl"

#LDAP acl
mandriva_dit_access_patch_template="templates/mandriva-dit-access.patch.tpl"
kerberos_acls_template="templates/kerberos-acls.ldif.tpl"

#kerberos configuration and acl files templates 
krb5_conf_template="templates/krb5.conf.tpl"
kdc_conf_template="templates/kdc.conf.tpl"
kadm5_acl_template="templates/kadm5.acl.tpl"

#patches for /etc/init.d/krb5kdc and /etc/init.d/kadmin
krb5kdc_init_patch="templates/krb5kdc-init.patch"
kadmin_init_patch="templates/kadmin-init.patch"

#kerberos.ini for mmc template
kerberos_ini_template="templates/kerberos.ini.tpl"

SLAPTEST="/usr/sbin/slaptest"
SLAPADD="/usr/sbin/slapadd"
LDAPMODIFY="/usr/bin/ldapmodify"
LDAPADD="/usr/bin/ldapadd"

LDAP="slapd"

#port for password changing
KPASSWDPORT=464

            
suffix=`get_ldap_base_dn`
adminpass=`get_ldap_admin_password`
            

`../check_configured.sh`
configured=$?

#realm name
realm="`echo $1|tr '[a-z]' '[A-Z]'`"
dnsdomain="$2"
#KDC host name
kdchost="$3"

#KDC relative host name
kdchostname=`echo $kdchost |awk -F. '{ print $1 }'`

#KDC port number
kdcport="$4"
if [ "x$kdcport" = "x" ];then
    kdcport="88"
fi    

#administration server port number
kadminport="$5"
if [ "x$kadminport" = "x" ];then
    kadminport="749"
fi    


#KDC database master key
#to do: to think about need of this checking
kdcmasterkey="$6"
if [ $configured -eq 0 ];then
    if [ "x$kdcmasterkey" = "x" ];then
	exit 1
    fi  
fi    

#DNS lookup for KDC
dnslookupkdc="${7}"
if [ "$dnslookupkdc" = "on" ];then
    dnslookupkdc="true"
else
    dnslookupkdc="false"
fi  

#DNS lookup for realm
dnslookuprealm="${8}"
if [ "$dnslookuprealm" = "on" ];then
    dnslookuprealm="true"
else
    dnslookuprealm="false"
fi  

DEFAULTENC="des3-cbc-sha1-kd des-cbc-crc"

#supported list of session key encryption types that should be returned by the KDC
defaulttgsenc="${9}"
if [ "x$defaulttgsenc" = "x" ];then
    defaulttgsenc="$DEFAULTENC"
fi  

#supported list of session key encryption types that should be requested by the client
defaulttktenc="${10}"
if [ "x$defaulttktenc" = "x" ];then
    defaulttktenc="$DEFAULTENC"
fi  

#all encryption types that are permitted for use in session key encryption
permittedenc="${11}"
if [ "x$permittedenc" = "x" ];then
    permittedenc="$DEFAULTENC"
fi  

#if set to 0 (for false), then weak encryption types will be filtered out
allowweak="${12}"
if [ "$allowweak" = "on" ];then
    allowweak="true"
else
    allowweak="false"
fi  

#maximum allowable amount of clockskew in seconds
clock="${13}"
if [ "x$clock" = "x" ];then
    clock="300"
fi  

#Load to DNS zone
dnsload="${14}"
if [ "$dnsload" = "on" ];then
    dnsload="true"
else
    dnsload="false"
fi  


#check hostname. it shld be fully qualified.
#to do : check is this rly need?
fqdn=`hostname -f`
if [ -z "$fqdn" ]; then
    _T 2 $"Failed to get %s of the server host" FQDN
    exit 1
fi

if [ $dnsload = "true" ];then
    #dns plugin must be installed and configured
    #check LDAP record of current DNS zone
    s=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" "(ou=$dnsdomain)"`
    if [ -z "$s" ]; then
        _T 2 $"Failed to find zone %s in %s database" $dnsdomain LDAP
        _T 2 $"%s is not configured for %s" DNS Kerberos
        _T 2 $"To configure %s for %s you have to do the next steps" DNS Kerberos
        _T 2 $"- login into %s: %s" "MMC" "http://@HOSTNAME@/mmc/"
        _T 2 $"- add %s zone %s where is located the server host" DNS $dnsdomain
        _T 2 $"- add host %s pointed to %s to the new created zone" $kdchostname @HOSTNAME@
        _T 2 $"- reload %s service" DNS
        _T 2 $"- make sure that %s on your server has a name server for the created zone" /etc/resolv.conf
        exit 1
    fi    

    #check LDAP record of KDC host in current DNS zone
    s=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" "(relativeDomainName=$kdchostname)"`
    if [ -z "$s" ]; then
        _T 2 $"Failed to find host %s.%s in %s database" $kdchostname $dnsdomain LDAP
        _T 2 $"%s is not configured for %s" DNS Kerberos
        _T 2 $"To configure %s for %s you have to do the next steps" DNS Kerberos
        _T 2 $"- login into %s: %s" "MMC" "http://@HOSTNAME@/mmc/"
        _T 2 $"- add host %s pointed to %s to zone %s" $kdchostname @HOSTNAME@ $dnsdomain
        _T 2 $"- make sure that %s on your server has a name server for the created zone" /etc/resolv.conf
        exit 1
    fi    
fi

#check whether KDC host name can be resolved to an IP address
ip=`host -W 3s "$kdchostname.$dnsdomain"|grep 'address'|sed "s/ *//g;s/^.*address//g"`
if [ -z "$ip" ]; then
    _T 2 $"Failed to resolve %s host name to %s address" KDC IP
# !uncomment
#    exit 1
#
fi

#check whether KDC host IP address can be resolved to a host name
h=`host -W 3s $ip|grep 'domain name pointer'|sed "s/ *//g;s/^.*pointer//g"`
if [ -z "$h" ]; then
    _T 2 $"Failed to resolve %s %s address to host name" KDC IP
# !uncomment
#    exit 1
#
fi

#KDC host is LDAP server
ldaphost="$kdchostname.$dnsdomain" 

#adding kerberos schema
add_schema_ldif schema/kerberos.ldif

##generate passwords for kdc and kadmin
kdc_passwd=`generate_password`
kadmin_passwd=`generate_password`

##LDAP db modifications
                                                                                                                                            
backup_db=`mybackup_dir /var/lib/ldap`
backup_config_db=`mybackup_dir /etc/openldap/slapd.d`


#test and load records for kerberos kdc and kadmin into LDAP
# kerberos root branch
tmpldif=`make_temp`
tmpdataldif=`make_temp`

res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "$suffix" "(ou=kerberos)"`
if [[ "$res" ]]; then
    #delete
    #ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "ou=kerberos,$suffix"
    _T 7 $"%s branch already exists in %s database" kerberos LDAP
else
    #add
    echo "">$tmpldif
    echo "">$tmpdataldif
    echo "dn: ou=kerberos,@SUFFIX@">$tmpldif
    echo "ou: kerberos">>$tmpldif
    echo "objectClass: organizationalUnit">>$tmpldif

    replace_placeholders $tmpldif $tmpdataldif

    #test load
    $SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to do a test load of %s branch into %s database" kerberos LDAP
        _T 2 $"%s file used: %s" ldif $tmpdataldif
        _T 2 $"%s file used: %s" slapd.conf $myslapdconf
        exit 1
    else
        #actual load
        $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
        if [ $? -ne 0 ]; then
            _T 2 $"Failed to load %s branch into %s database" kerberos LDAP
            _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
            clear
            exit 1
        fi
        _T 7 $"%s branch has been loaded into %s database" kerberos LDAP
    fi
fi

# kdc
add="true"
res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=System Accounts,$suffix" "(uid=kdc)"`
if [[ "$res" ]]; then
    if [ $configured -eq 0 ]; then
        # initial configure:
        #delete
        ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "uid=kdc,ou=System Accounts,$suffix"
    else
        _T 7 $"%s data has been loaded into %s database already" KDC LDAP
        add="false"
    fi
fi

if [ $add = "true" ];then
    #add
    echo "">$tmpldif
    echo "">$tmpdataldif
    echo "dn: uid=kdc,ou=System Accounts,@SUFFIX@">>$tmpldif
    echo "uid: kdc">>$tmpldif
    echo "objectClass: account">>$tmpldif
    echo "objectClass: simpleSecurityObject">>$tmpldif
    echo "userPassword: @KDCPASSWD@">>$tmpldif
    echo "description: Default bind DN for the Kerberos KDC server">>$tmpldif

    replace_placeholders $tmpldif $tmpdataldif

    #test load
    $SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to do a test load of %s data into %s database" KDC LDAP
        _T 2 $"%s file used: %s" ldif $tmpdataldif
        _T 2 $"%s file used: %s" slapd.conf $myslapdconf
        exit 1
    else
        #actual load
        $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
        if [ $? -ne 0 ]; then
            _T 2 $"Failed to load %s data into %s database" KDC LDAP
            _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
            clear
            exit 1
        fi
        _T 7 $"%s data has been loaded into %s database" KDC LDAP
    fi
fi

# kadmin
add="true"
res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=System Accounts,$suffix" "(uid=kadmin)"`
if [[ "$res" ]]; then
    if [ $configured -eq 0 ]; then
        # initial configure:
        #delete
        ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "uid=kadmin,ou=System Accounts,$suffix"
    else
        _T 7 $"%s data has been loaded into %s database already" kadmin LDAP
        add="false"
    fi
fi

if [ $add = "true" ];then
    #add
    echo "">$tmpldif
    echo "">$tmpdataldif
    echo "dn: uid=kadmin,ou=System Accounts,@SUFFIX@">>$tmpldif
    echo "uid: kadmin">>$tmpldif
    echo "objectClass: account">>$tmpldif
    echo "objectClass: simpleSecurityObject">>$tmpldif
    echo "userPassword: @KADMINPASSWD@">>$tmpldif
    echo "description: Default bind DN for the Kerberos Administration server">>$tmpldif

    replace_placeholders $tmpldif $tmpdataldif

    #test load
    $SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to do a test load of %s data into %s database" kadmin LDAP
        _T 2 $"%s file used: %s" ldif $tmpdataldif
        _T 2 $"%s file used: %s" slapd.conf $myslapdconf
        exit 1
    else
        #actual load
        $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
        if [ $? -ne 0 ]; then
            _T 2 $"Failed to load %s data into %s database" kadmin LDAP
            _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
            clear
            exit 1
        fi
        _T 7 $"%s data has been loaded into %s database" kadmin LDAP
    fi
fi

# Kerberos Admins group
res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=System Groups,$suffix" "(cn=Kerberos Admins)"`
if [[ "$res" ]]; then
    #delete
    ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "cn=Kerberos Admins,ou=System Groups,$suffix"
fi
    
#add
echo "">$tmpldif
echo "">$tmpdataldif
echo "dn: cn=Kerberos Admins,ou=System Groups,@SUFFIX@">>$tmpldif
echo "cn: Kerberos Admins">>$tmpldif
echo "objectClass: groupOfNames">>$tmpldif
echo "description: Members can write entries and attributes under ou=kerberos">>$tmpldif
echo "owner: uid=kadmin,ou=System Accounts,@SUFFIX@">>$tmpldif
echo "member: uid=kadmin,ou=System Accounts,@SUFFIX@">>$tmpldif

replace_placeholders $tmpldif $tmpdataldif

#test load
$SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
if [ $? -ne 0 ]; then
    _T 2 $"Failed to do a test load of %s data into %s database" "Kerberos Admins" LDAP
    _T 2 $"%s file used: %s" ldif $tmpdataldif
    _T 2 $"%s file used: %s" slapd.conf $myslapdconf
    exit 1
else
    #actual load
    $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to load %s data into %s database" "Kerberos Admins"  LDAP
        _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
        clear
        exit 1
    fi
    _T 7 $"%s data has been loaded into %s database" "Kerberos Admins" LDAP
fi

# Kerberos Readers group
res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=System Groups,$suffix" "(cn=Kerberos Readers)"`
if [[ "$res" ]]; then
    #delete
    ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "cn=Kerberos Readers,ou=System Groups,$suffix"
fi

#add
echo "">$tmpldif
echo "">$tmpdataldif
echo "dn: cn=Kerberos Readers,ou=System Groups,@SUFFIX@">>$tmpldif
echo "cn: Kerberos Readers">>$tmpldif
echo "objectClass: groupOfNames">>$tmpldif
echo "description: Members can read entries and attributes under ou=kerberos">>$tmpldif
echo "owner: uid=kadmin,ou=System Accounts,@SUFFIX@">>$tmpldif
echo "member: uid=kdc,ou=System Accounts,@SUFFIX@">>$tmpldif

replace_placeholders $tmpldif $tmpdataldif

#test load
$SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
if [ $? -ne 0 ]; then
    _T 2 $"Failed to do a test load of %s data into %s database" "Kerberos Readers" LDAP
    _T 2 $"%s file used: %s" ldif $tmpdataldif
    _T 2 $"%s file used: %s" slapd.conf $myslapdconf
    exit 1
else
    #actual load
    $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to load %s data into %s database" "Kerberos Readers" LDAP
        _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
        clear
        exit 1
    fi
    _T 7 $"%s data has been loaded into %s database" "Kerberos Readers" LDAP
fi

if [ $dnsload = "true" ];then
    res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" "(relativeDomainName=kerberos)"`
    if [[ "$res" ]]; then
        #delete
        ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "relativeDomainName=kerberos,ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" 
    fi
    #add
    echo "">$tmpldif
    echo "">$tmpdataldif
    echo "dn: relativeDomainName=kerberos,ou=@DNSDOMAIN@,ou=@DNSDOMAIN@,ou=DNS,@SUFFIX@">>$tmpldif
    echo "objectClass: top">>$tmpldif
    echo "objectClass: dNSZone">>$tmpldif
    echo "dNSClass: IN">>$tmpldif
    echo "zoneName: @DNSDOMAIN@">>$tmpldif
    echo "cNAMERecord: @HOST@">>$tmpldif
    echo "relativeDomainName: kerberos">>$tmpldif
    echo "#structuralObjectClass: dNSZone">>$tmpldif
    
    replace_dns_placeholders $tmpldif $tmpdataldif
    #test load
    $SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to do a test load of %s record to %s DNS zone" kerberos $dnsdomain
        _T 2 $"%s file used: %s" ldif $tmpdataldif
        _T 2 $"%s file used: %s" slapd.conf $myslapdconf
        exit 1
    else
        #actual load
        $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
        if [ $? -ne 0 ]; then
            _T 2 $"Failed to add %s record to %s DNS zone" kerberos $dnsdomain
            _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
            clear
            exit 1
        fi
        _T 7 $"%s record has been added to %s DNS zone" kerberos $dnsdomain
    fi

    res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" "(relativeDomainName=_kerberos._udp)"`
    if [[ "$res" ]]; then
        #delete
        ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "relativeDomainName=_kerberos._udp,ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" 
    fi
    #add
    echo "">$tmpldif
    echo "">$tmpdataldif
    echo "dn: relativeDomainName=_kerberos._udp,ou=@DNSDOMAIN@,ou=@DNSDOMAIN@,ou=DNS,@SUFFIX@">>$tmpldif
    echo "objectClass: top">>$tmpldif
    echo "objectClass: dNSZone">>$tmpldif
    echo "dNSClass: IN">>$tmpldif
    echo "zoneName: @DNSDOMAIN@">>$tmpldif
    echo "sRVRecord: 0 0 @KDC_PORT@ @HOST@">>$tmpldif
    echo "relativeDomainName: _kerberos._udp">>$tmpldif
    echo "#structuralObjectClass: dNSZone">>$tmpldif
    
    replace_dns_placeholders $tmpldif $tmpdataldif
    #test load
    $SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to do a test load of %s record to %s DNS zone" _kerberos._udp $dnsdomain
        _T 2 $"%s file used: %s" ldif $tmpdataldif
        _T 2 $"%s file used: %s" slapd.conf $myslapdconf
        exit 1
    else
        #actual load
        $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
        if [ $? -ne 0 ]; then
            _T 2 $"Failed to add %s record to %s DNS zone" _kerberos._udp $dnsdomain
            _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
            clear
            exit 1
        fi
        _T 7 $"%s record has been added to %s DNS zone" _kerberos._udp $dnsdomain
    fi

    res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" "(relativeDomainName=_kerberos-master._udp)"`
    if [[ "$res" ]]; then
        #delete
        ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "relativeDomainName=_kerberos-master._udp,ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" 
    fi
    #add
    echo "">$tmpldif
    echo "">$tmpdataldif
    echo "dn: relativeDomainName=_kerberos-master._udp,ou=@DNSDOMAIN@,ou=@DNSDOMAIN@,ou=DNS,@SUFFIX@">>$tmpldif
    echo "objectClass: top">>$tmpldif
    echo "objectClass: dNSZone">>$tmpldif
    echo "dNSClass: IN">>$tmpldif
    echo "zoneName: @DNSDOMAIN@">>$tmpldif
    echo "sRVRecord: 0 0 @KDC_PORT@ @HOST@">>$tmpldif
    echo "relativeDomainName: _kerberos-master._udp">>$tmpldif
    echo "#structuralObjectClass: dNSZone">>$tmpldif
    
    replace_dns_placeholders $tmpldif $tmpdataldif
    #test load
    $SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to do a test load of %s record to %s DNS zone" _kerberos-master._udp $dnsdomain
        _T 2 $"%s file used: %s" ldif $tmpdataldif
        _T 2 $"%s file used: %s" slapd.conf $myslapdconf
        exit 1
    else
        #actual load
        $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
        if [ $? -ne 0 ]; then
            _T 2 $"Failed to add %s record to %s DNS zone" _kerberos-master._udp $dnsdomain
            _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
            clear
            exit 1
        fi
        _T 7 $"%s record has been added to %s DNS zone" _kerberos-master._udp $dnsdomain
    fi

    res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" "(relativeDomainName=_kerberos-adm._tcp)"`
    if [[ "$res" ]]; then
        #delete
        ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "relativeDomainName=_kerberos-adm._tcp,ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" 
    fi
    #add
    echo "">$tmpldif
    echo "">$tmpdataldif
    echo "dn: relativeDomainName=_kerberos-adm._tcp,ou=@DNSDOMAIN@,ou=@DNSDOMAIN@,ou=DNS,@SUFFIX@">>$tmpldif
    echo "objectClass: top">>$tmpldif
    echo "objectClass: dNSZone">>$tmpldif
    echo "dNSClass: IN">>$tmpldif
    echo "zoneName: @DNSDOMAIN@">>$tmpldif
    echo "sRVRecord: 0 0 @KADMIN_PORT@ @HOST@">>$tmpldif
    echo "relativeDomainName: _kerberos-adm._tcp">>$tmpldif
    echo "#structuralObjectClass: dNSZone">>$tmpldif
    
    replace_dns_placeholders $tmpldif $tmpdataldif

    #test load

    $SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to do a test load of %s record to %s DNS zone" _kerberos-adm._tcp $dnsdomain
        _T 2 $"%s file used: %s" ldif $tmpdataldif
        _T 2 $"%s file used: %s" slapd.conf $myslapdconf
        exit 1
    else
        #actual load
        $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
        if [ $? -ne 0 ]; then
            _T 2 $"Failed to add %s record to %s DNS zone" _kerberos-adm._tcp $dnsdomain
            _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
            clear
            exit 1
        fi
        _T 7 $"%s record has been added to %s DNS zone" _kerberos-adm._tcp $dnsdomain
    fi


    res=`ldapsearch -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -LLL -b "ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" "(relativeDomainName=_kpasswd._udp)"`
    if [[ "$res" ]]; then
        #delete
        ldapdelete -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" "relativeDomainName=_kpasswd._udp,ou=$dnsdomain,ou=$dnsdomain,ou=dns,$suffix" 
    fi
    #add
    echo "">$tmpldif
    echo "">$tmpdataldif
    echo "dn: relativeDomainName=_kpasswd._udp,ou=@DNSDOMAIN@,ou=@DNSDOMAIN@,ou=DNS,@SUFFIX@">>$tmpldif
    echo "objectClass: top">>$tmpldif
    echo "objectClass: dNSZone">>$tmpldif
    echo "dNSClass: IN">>$tmpldif
    echo "zoneName: @DNSDOMAIN@">>$tmpldif
    echo "sRVRecord: 0 0 @KPASSWD_PORT@ @HOST@">>$tmpldif
    echo "relativeDomainName: _kpasswd._udp">>$tmpldif
    echo "#structuralObjectClass: dNSZone">>$tmpldif
    
    replace_dns_placeholders $tmpldif $tmpdataldif
    #test load
    $SLAPADD -u -b "$suffix" -l $tmpdataldif > /dev/null
    if [ $? -ne 0 ]; then
        _T 2 $"Failed to do a test load of %s record to %s DNS zone" _kpasswd._udp $dnsdomain
        _T 2 $"%s file used: %s" ldif $tmpdataldif
        _T 2 $"%s file used: %s" slapd.conf $myslapdconf
        exit 1
    else
        #actual load
        $LDAPADD -x -w "$adminpass" -D "uid=LDAP Admin,ou=System Accounts,$suffix" -f $tmpdataldif > /dev/null
        if [ $? -ne 0 ]; then
            _T 2 $"Failed to add %s record to %s DNS zone" _kpasswd._udp $dnsdomain
            _T 2 $"Your previous %s database has been backed up as %s" LDAP "$backup_db"
            clear
            exit 1
        fi
        _T 7 $"%s record has been added to %s DNS zone" _kpasswd._udp $dnsdomain
    fi
fi

if [ $configured -eq 0 ]; then
    # initial configure:
    #LDAP acls
    
    tmpacls=`make_temp`
	
    #getting ACL count. 
    acl_count=`ldapsearch -x -D "cn=config" -w $adminpass -b "cn=config" "(olcDatabase={2}bdb)" olcAccess | grep olcAccess: -c`
    #index last of acl: ldap acl indexing starts from 0
    index=$((acl_count-1))
    #adding kerberos acls in pos <index>: before the last acl that enables access to reading
	
    cat $kerberos_acls_template | sed -e "\
	s/@SUFFIX@/$suffix/g;\
	s/@REALM@/$realm/g;\
	s/@INDEX@/$index/g;" > $tmpacls
	
    $LDAPADD -x -D "cn=config" -w $adminpass -H ldap://localhost:389 -f $tmpacls > /dev/null
    if [ $? -ne 0 ]; then
	_T 2 $"Failed to register %s %s in the %s config database" kerberos ACLs LDAP
	_T 2 $"Your previous %s database has been backed up as %s" "LDAP config" $backup_config_db
        exit 1
    fi
    _T 7 $"%s %s have been registered in the %s config database" Kerberos ACLs LDAP
fi

# dns restart
do_service_action_critically named restart /var/log/messages

#Kerberos

#try stop just in case
do_service_action krb5kdc stop
do_service_action kadmin stop


###/etc/krb5.conf
backup /etc/krb5.conf

mkdir -p /var/log/kerberos

if [ $dnslookupkdc = "true" ];then
    comment="#"    
else
    comment=""    
fi    

cat $krb5_conf_template | sed -e "\
s/@SUFFIX@/$suffix/g;\
s/@REALM@/$realm/g;\
s/@HOST@/$kdchostname/g;\
s/@DNSDOMAIN@/$dnsdomain/g;\
s/@KADMIN_PORT@/$kadminport/g;\
s/@DNSLOOKUPREALM@/$dnslookuprealm/g;\
s/@DNSLOOKUPKDC@/$dnslookupkdc/g;\
s/@COMMENT@/$comment/g;\
s/@DEFAULTTGSENC@/$defaulttgsenc/g;\
s/@DEFAULTTKTENC@/$defaulttktenc/g;\
s/@PERMITTEDENC@/$permittedenc/g;\
s/@ALLOWWEAK@/$allowweak/g;\
s/@CLOCK@/$clock/g" > /etc/krb5.conf
       

###/etc/kerberos/krb5kdc/kdc.conf
backup /var/kerberos/krb5kdc/kdc.conf
cat $kdc_conf_template | sed -e "\
s/@REALM@/$realm/;\
s/@KDC_PORT@/$kdcport/g" > /var/kerberos/krb5kdc/kdc.conf

###/etc/kerberos/krb5kdc/kadm5.acl
cat $kadm5_acl_template > /var/kerberos/krb5kdc/kadm5.acl
sed -i "s/\@REALM\@/$realm/" /var/kerberos/krb5kdc/kadm5.acl

if [ $configured -eq 0 ]; then
    
    ###/etc/kerberos/krb5kdc/kadm5.keytab
    rm -f /var/kerberos/krb5kdc/kadm5.keytab

    #patching /etc/init.d/krb5kdc and /etc/init.d/kadmin to start after ldap and named

    backup /etc/init.d/krb5kdc
    patch -p0 /etc/init.d/krb5kdc -i $krb5kdc_init_patch

    backup /etc/init.d/kadmin
    patch -p0 /etc/init.d/kadmin -i $kadmin_init_patch

    #create realm 
    res=`kdb5_ldap_util -D "uid=LDAP Admin,ou=System Accounts,$suffix" -w $adminpass create -subtrees ou=kerberos,$suffix -P $kdcmasterkey -r $realm -s -H ldap://localhost| grep "Initializing database"`
    if [ -z "$res" ]; then 
	_T 2 $"Failed to create a realm %s" $realm
	exit 1
    fi
    _T 7 $"Realm %s has been created" $realm

    #stash passwords for kdc and kadmin
    echo -en "$kdc_passwd\\n$kdc_passwd"|kdb5_ldap_util -D "cn=LDAP Admin,ou=System Accounts,$suffix" -w $adminpass stashsrvpw -f /var/kerberos/service.keyfile "uid=kdc,ou=System Accounts,$suffix"
    if [ $? -ne 0 ]; then 
	_T 2 $"Failed to stash password for %s" KDC
	exit 1
    fi

    echo -en "$kadmin_passwd\\n$kadmin_passwd"|kdb5_ldap_util -D "cn=LDAP Admin,ou=System Accounts,$suffix" -w $adminpass stashsrvpw -f /var/kerberos/service.keyfile "uid=kadmin,ou=System Accounts,$suffix"
    if [ $? -ne 0 ]; then 
    	_T 2 $"Failed to stash password for %s" kadmin
	exit 1
    fi
    
    _T 7 $"Passwords for %s and %s have been stashed" KDC kadmin

    #stash system principals' passwords into default keytab file
    res=`kadmin.local -q "ktadd kadmin/admin kadmin/changepw"|grep "added"`
    if [ -z "$res" ]; then 
        _T 2 $"Failed to stash passwords for system principals %s and %s" kadmin/admin kadmin/changepw
	exit 1
    fi
    
    _T 7 $"Passwords for system principals %s and %s have been stashed" kadmin/admin kadmin/changepw

    #add default policy and ldap's principal ldap/{host}
    kadmin.local -q "add_policy -maxlife 180days -minlife 2days -minlength 5 -minclasses 1 default"
    

    res=`kadmin.local -q "addprinc -randkey ldap/$ldaphost"|grep "created"`
    if [ -z "$res" ]; then 
	_T 2 $"Failed to create a principal for %s host" KDC
        exit 1
    fi
    _T 7 $"Principal for %s host has been created" KDC

    #stash his password into default keytab file
        
    res=`kadmin.local -q  "ktadd ldap/$ldaphost"|grep "added"`
    if [ "x$res" == "x" ]; then 
	_T 2 $"Failed to stash password for %s host" KDC
        exit 1
    fi

    _T 7 $"Password for %s host has been stashed" KDC
fi


#kerberos.ini for mmc
backup /etc/mmc/plugins/kerberos.ini > /dev/null 2>&1

cat $kerberos_ini_template | sed -e "\
s/@REALM@/$realm/g" > /etc/mmc/plugins/kerberos.ini

_T 7 $"%s has been configured" RDS


do_service_action_critically krb5kdc start /var/log/kerberos/krb5kdc.log
do_service_action_critically kadmin start /var/log/kerberos/kadmin.log
do_service_action_critically slapd restart /var/log/ldap/ldap.log
do_service_action_critically mmc-agent restart /var/log/mmc/mmc-agent


#adding to autorun
chkconfig krb5kdc on
chkconfig kadmin on

_T 8 $"%s module has been activated in the %s interface" Kerberos RDS
_T 7 $"You can add %s principals from the %s interface: %s" kerberos RDS http://@HOSTNAME@/mmc/

