#!/bin/bash
# Copyright Mandriva 2009, 2010 all rights reserved
if [ "`id -u`" != "0" ]; then
	echo "Error, must be root user"
	exit 1
fi

function get_max_empty_service_uid(){
    local MAX_SERVICE_UID=499
    local uid=$MAX_SERVICE_UID
    while [  $uid -gt 0 ]; do
	user=`getent passwd | awk -v uid=$uid -F: '$3 == uid'`
	if [ -z "$user" ]; then
	    #echo "empty uid is $uid"
	    break
	fi
	let uid=uid-1
    done
    echo "$uid"
}

. '../../functions.sh'
set_locale_settings

mdssuffix=`get_ldap_base_dn`
mdsserver=127.0.0.1

main_cf_template="templates/main.cf.tpl"
master_cf_template="templates/master.cf.tpl"

mail_ini_template="templates/mail.ini.tpl"
dovecot_ldap_template="templates/dovecot-ldap.conf.tpl"
dovecot_template="templates/dovecot.conf.tpl"
ldap_accounts_cf="templates/ldap-accounts.cf"
ldap_aliases_cf="templates/ldap-aliases.cf"
ldap_domains_cf="templates/ldap-domains.cf"
ldap_maildrop_cf="templates/ldap-maildrop.cf"
ldap_transport_cf="templates/ldap-transport.cf"
openssl_cnf_template="templates/openssl.cnf.tpl"
amavis_template="templates/amavisd.conf.tpl"
spamassassin_template="templates/local.cf.tpl"

smtpd_myhostname="$1"
# always authorize localhost
smtpd_mynetworks="127.0.0.1/32"
# add networks specified in wizard
for network in $2
do
    smtpd_mynetworks=$smtpd_mynetworks,$network
done
popimap_proto="$3"


hostname=`echo $smtpd_myhostname | sed 's/\..*//g'`

# postfix
backup /etc/postfix/main.cf
cat $main_cf_template | sed -e "\
    s/@FQDN@/$smtpd_myhostname/g;\
    s/@HOSTNAME@/$hostname/g;\
    s|@MYNETWORKS@|$smtpd_mynetworks|g;" > /etc/postfix/main.cf

backup /etc/postfix/master.cf
cat $master_cf_template > /etc/postfix/master.cf

for template in $ldap_accounts_cf $ldap_aliases_cf $ldap_domains_cf $ldap_maildrop_cf $ldap_transport_cf
do
    newfile="/etc/postfix/`basename $template`"
    cat $template | sed -e "\
	s/@HOST@/$mdsserver/g;\
	s/@SUFFIX@/$mdssuffix/g;" > $newfile
done


vmail_uid=`get_max_empty_service_uid`

adduser -r -g mail --uid $vmail_uid vmail > /dev/null 2>&1
mkdir -p /home/vmail > /dev/null 2>&1
chown vmail:mail /home/vmail


# dovecot

backup /etc/dovecot/dovecot.conf
cat $dovecot_template | sed -e "\
    s/@PROTOCOLS@/$popimap_proto/g;\
    s/@VMAIL_UID@/$vmail_uid/g;" > /etc/dovecot/dovecot.conf


dovecot_ldap_conf=/etc/dovecot-ldap.conf
if [ -f $dovecot_ldap_conf ]; then 
    backup $dovecot_ldap_conf
fi

cat $dovecot_ldap_template | sed -e "\
    s/@SUFFIX@/$mdssuffix/g;\
    s/@HOST@/$mdsserver/g;" > $dovecot_ldap_conf
    

# certificates gen

ssl_conf=/tmp/openssl.cnf
cat $openssl_cnf_template | sed -e "\
    s/@COMMONNAME@/$smtpd_myhostname.$smptd_myorigin/g;\
    s/@DOMAIN@/$smptd_myorigin/g;" > $ssl_conf

mkdir -p /etc/ssl/mss/certs
mkdir -p /etc/ssl/mss/private
openssl req -x509 -new \
    -config $ssl_conf \
    -out /etc/ssl/mss/certs/smtpd.pem \
    -keyout /etc/ssl/mss/private/smtpd.key \
    -days 730 -nodes -batch > /dev/null 2>&1
rm -f $ssl_conf

chmod 600 /etc/ssl/mss/private/smtpd.key


# mmc conf
backup /etc/mmc/plugins/mail.ini
cat $mail_ini_template > /etc/mmc/plugins/mail.ini
sed -i "s/\@SUFFIX\@/$mdssuffix/" /etc/mmc/plugins/mail.ini

# amavis configuration
mkdir -p /var/amavis/tmp
mkdir -p /var/amavis/db
chown -R amavis:amavis /var/amavis

backup /etc/amavisd/amavisd.conf
cat $amavis_template | sed -e "\
    s/@SUFFIX@/$mdssuffix/g;\
    s/@FQDN@/$smtpd_myhostname/g;" > /etc/amavisd/amavisd.conf

chmod 640 /etc/amavisd/amavisd.conf

# amavis / clamav
usermod -aG amavis clamav 2>/dev/null
usermod -aG amavis clam
#usermod -aG clamav clamd

# amavis / razor
su - amavis -s /bin/sh -c 'razor-admin -d --create && razor-admin -register && razor-admin -discover' 2>&1 > /dev/null
if [ $? -eq 0 ]; then
    _T 0 $"%s has been configured" Razor
else 
    su - amavis -s /bin/sh -c 'razor-admin -register && razor-admin -discover' 2>&1 > /dev/null
    if [ $? -eq 0 ]; then 
	_T 0 $"%s has been configured" Razor
    else 
	_T 1 $"Failed to register %s" razor 
	_T 1 $"Try to run under the %s user: %s" root "su - amavis -s /bin/sh -c 'razor-admin -register && razor-admin -discover'"
    fi
fi

# su - amavis -s /bin/sh -c 'pyzor discover'

# spamassassin
backup /etc/mail/spamassassin/local.cf
cat $spamassassin_template > /etc/mail/spamassassin/local.cf

#creating postfix chroot environment
./create_postfix_env.sh

do_service_action_critically mmc-agent restart /var/log/mmc/mmc-agent.log
do_service_action_critically amavisd restart /var/log/maillog
do_service_action_critically clamd restart /var/log/messages
do_service_action_critically postfix restart /var/log/maillog
do_service_action_critically dovecot restart /var/log/maillog

#adding to autorun
chkconfig amavisd on
chkconfig clamd on
chkconfig postfix on
chkconfig dovecot on

_T 8 $"Mail module has been activated in the %s interface: %s" RDS  http://@HOSTNAME@/mmc/
_T 7 $"You can create mail domains in the %s interface and specify mail adresses to users and groups" RDS
_T 7 $"- mails are stored in %s" "/home/vmail/user/Maildir"
_T 7 $"- %s has been enabled on the %s server" SSL SMTP
_T 7 $"- Non-%s connections on external interfaces have been disabled by default on the %s server" SSL IMAP
_T 7 $"- Networks authorized to send mail without authentication: %s" $smtpd_mynetworks
_T 8 $"Make sure you have enabled mail services (%s 25, %s 465, %s 995, %s 993) on your firewall" SMTP SMTPS POPS IMAPS

exit 0

