#!/bin/bash
# Copyright Mandriva 2009, 2010 all rights reserved

if [ "`id -u`" != "0" ]; then
	echo "Error, must be root user"
	exit 1
fi


. '../../functions.sh'
set_locale_settings



ldap_config_dir="/etc/openldap/slapd.d"
ldap_cert="/etc/pki/tls/certs/ldap.pem"
ldap_key="/etc/pki/tls/private/ldap.pem"

function generate_cert_key(){
    CERTS_DIR=/etc/pki/tls/certs
    KEYS_DIR=/etc/pki/tls/private

    # optionally create new directories
    mkdir -p $CERTS_DIR
    mkdir -p $KEYS_DIR

    # create server/CA cert and private key without passphrase
    # valid for 10 years using current RSA recommendations for key size
    # RSA is used as the key-exchange protocol
    openssl req -x509 -nodes -days 3650 -newkey rsa:2048 -config templates/openssl.conf.tpl -keyout $ldap_key -out $ldap_cert  > /dev/null 2>&1
  
    # set permissions
    chown ldap:ldap $ldap_key $ldap_cert
    chmod 0400 $ldap_key
}


SLAPTEST="/usr/sbin/slaptest"
SLAPADD="/usr/sbin/slapadd"
SLAPPASSWD="/usr/sbin/slappasswd"

DB_CONFIG="/var/lib/ldap/DB_CONFIG"


overlays_ldif="templates/module.ldif"
overlays_modify_ldif="templates/module.ldif.tpl"
dbindex_ldif="templates/dbindex.ldif"
certs_modify_ldif="templates/certs.ldif.tpl"

base_mds_template="templates/base.ini.tpl"
ppolicy_template="templates/ppolicy.ini.tpl"
base_ldif_template="templates/init.ldif.tpl"
DB_CONFIG_template="templates/DB_CONFIG.tpl"
acl_template="templates/acl.ldif.tpl"
slapd_conf_template="templates/slapd.conf.tpl"
ppolicy_ldif_template="templates/ppolicy.ldif.tpl"

pam_ldap_conf_template="templates/pam_ldap.conf.tpl"
nsswitch_template="templates/nsswitch.conf.tpl"
nslcd_conf_template="templates/nslcd.conf.tpl"

nslcd_conf=/etc/nslcd.conf
hostsfile="/etc/hosts"
networkfile="/etc/sysconfig/network"

cnconfigadmin="cn=config"

mydomain=$1
mypass_e=`escape_sed $2`
mypass=$2
ppolicy=$3

sethostname=$4
hostname=$5
ipaddress=$6

backup_dir=$7

tmpfile=`make_temp`

if [ "$sethostname" == "on" ]; then
    sed -i "1 s/^/$ipaddress\t\t$hostname\n/;" $hostsfile
    res=`cat $networkfile|grep HOSTNAME`
    if [ "x$res" = "x" ];then
        sed -i "1 s/^/HOSTNAME=$hostname\n/;" $networkfile
    else
        sed -e "s/^HOSTNAME=.*$/HOSTNAME=$hostname\n/g" $networkfile>$tmpfile
        cat $tmpfile>$networkfile
    fi
fi

check_host_fqdn

myfqdn=`hostname -f 2>/dev/null`
if [ -z "$myfqdn" ]; then
	myfqdn="localhost"
fi


#backup ldap configuration

if [ -e $ldap_config_dir ]; then
    backup_dir $ldap_config_dir
    rm -rf $ldap_config_dir
fi


mkdir -p $ldap_config_dir
$SLAPTEST -f $slapd_conf_template -F $ldap_config_dir > /dev/null 2>&1
chown ldap:ldap $ldap_config_dir -R

check_ldap_config_critically "$ldap_config_dir"

#update certs rights
mkdir -p /etc/openldap/certs/
chown 644 /etc/openldap/certs/* 2>/dev/null

#main ldif files
bdb_ldif=`_find $ldap_config_dir/cn=config bdb.ldif`
config_ldif=`_find $ldap_config_dir/cn=config config`


#openldap logging
ldap_log_dir="/var/log/ldap"

if [ ! -e $ldap_log_dir ]; then
    mkdir $ldap_log_dir
fi
chmod 755 $ldap_log_dir
chown ldap:ldap $ldap_log_dir
sed -i "/local4.*/d" /etc/rsyslog.conf
cat >> /etc/rsyslog.conf << EOF
local4.*                                                /var/log/ldap/ldap.log
EOF

do_service_action_critically rsyslog restart


#if [ ! -f $ldap_cert ] || [ ! -f $ldap_key ]; then
`generate_cert_key`
#fi



#suffix, password, server
mysuffix=`calc_suffix $mydomain`
pass=`$SLAPPASSWD -h {SSHA} -s "$mypass"`

if [ $? -eq 0 ]; then 
    _T 0 $"%s password has been generated successfully" "LDAP"
else
    _T 1 $"Error in generating %s password" "LDAP"
    exit 1
fi



#set password of `config` user

cat $config_ldif > $tmpfile

res=`cat $tmpfile|grep "olcRootPW"`
    if [ "x$res" = "x" ]; then 
	sed -i "/^olcRootDN/ a\olcRootPW: $pass" $tmpfile
    else
	sed -i "s\^olcRootPW: .*\olcRootPW: $pass\g" $tmpfile
    fi

cat $tmpfile>$config_ldif

check_ldap_config_critically "$ldap_config_dir"

#this part(till rm $tmpfile) can be replaced by ldapmodify operation over the bdb database executed by cn=config user with password=$pass
cat $bdb_ldif > $tmpfile

sed -i "s\^olcSuffix: .*\olcSuffix: $mysuffix\g" $tmpfile
sed -i "s\^olcRootDN: .*\olcRootDN: $mysuffix\g" $tmpfile

res=`cat $tmpfile|grep "olcRootPW"`
    if [ "x$res" = "x" ]; then 
	sed -i "/^olcRootDN/ a\olcRootPW: $pass" $tmpfile
    else
	sed -i "s\^olcRootPW:.*\olcRootPW: $pass\g" $tmpfile
    fi

cat $tmpfile > $bdb_ldif
rm $tmpfile

check_ldap_config_critically "$ldap_config_dir"

#DB_CONFIG
if [ -f $DB_CONFIG ];then
    backup $DB_CONFIG
fi
cp -f $DB_CONFIG_template $DB_CONFIG
chown ldap:ldap $DB_CONFIG

chown ldap /var/lib/ldap/__db.*
chown ldap /var/lib/ldap/alock


#misc.ldif (standard openldap schema) causes error because of mailhost attribute (conflicts with mail.ldif) 
#remove it
misc=`_find $ldap_config_dir/cn=config/cn=schema misc.ldif`
if [ -f $misc ]; then
    rm -f $misc
fi


#restart
do_service_action_critically slapd restart "/var/log/ldap/ldap.log"
#need some delay to get ldap fully loaded
sleep 1

# RDS schemas adding 
#misc is exluded
for schema_ldif in `ls ./schema/ | grep -v misc`; do
    add_schema_ldif schema/$schema_ldif "$mypass"
    if [ $? -gt 0 ]; then 
	exit 1
    fi
done


## base.ini
if [ "`uname -m`" = "x86_64" ]; then
    backup_tools_dir=/usr/lib64/mmc/backup-tools
else
    backup_tools_dir=/usr/lib/mmc/backup-tools
fi

backup /etc/mmc/plugins/base.ini
cat $base_mds_template > /etc/mmc/plugins/base.ini
sed -i "s/\@SUFFIX\@/$mysuffix/" /etc/mmc/plugins/base.ini
sed -i "s/\@PASSWORD\@/$mypass_e/" /etc/mmc/plugins/base.ini
sed -i "s/\@ROOTDN\@/$cnconfigadmin/" /etc/mmc/plugins/base.ini
sed -i "s/\@ROOTPW\@/$mypass/" /etc/mmc/plugins/base.ini
sed -i "s|\@BACKUP_TOOLS_DIR\@|$backup_tools_dir|" /etc/mmc/plugins/base.ini
sed -i "s|\@BACKUP_DIR\@|$backup_dir|" /etc/mmc/plugins/base.ini

mkdir -p $backup_dir > /dev/null 2>&1

if [ -f "/etc/samba/smb.conf" ]; then
    backup /etc/samba/smb.conf
    $(dirname $0)/setup-mmc-smb.py
    do_service_action smb restart
fi

## ppolicy.ini
backup /etc/mmc/plugins/ppolicy.ini
cat $ppolicy_template > /etc/mmc/plugins/ppolicy.ini
sed -i "s/\@SUFFIX\@/$mysuffix/" /etc/mmc/plugins/ppolicy.ini
if [ "$ppolicy" == "on" ]; then
    sed -i "s/\@DISABLE\@/0/" /etc/mmc/plugins/ppolicy.ini
else
    sed -i "s/\@DISABLE\@/1/" /etc/mmc/plugins/ppolicy.ini
fi


## /etc/openldap/ldap.conf
myldapconf=`make_temp`

cat /etc/openldap/ldap.conf | \
	sed -e "s/^BASE[[:blank:]]\+.*/BASE $mysuffix/g;\
	s/^HOST[[:blank:]]\+.*/HOST $myfqdn/g;\
	s@^URI[[:blank:]]\+.*@URI ldap://$myfqdn ldap://127.0.0.1@g" \
	> $myldapconf
if ! grep -qE '^(HOST|URI)' $myldapconf; then
	echo "URI ldap://$myfqdn ldap://127.0.0.1" >> $myldapconf
fi
if ! grep -qE '^BASE' $myldapconf; then
	echo "BASE $mysuffix" >> $myldapconf
fi

if ! grep -qE '^TLS_REQCERT' $myldapconf; then
	echo "TLS_REQCERT allow" >> $myldapconf
fi

chmod 0644 $myldapconf


#enabling ldap over ssl connection
myldap=`make_temp`
cat /etc/sysconfig/ldap | sed -e "s/^SLAPD_LDAPS\+.*/SLAPD_LDAPS=yes/g" > $myldap
cat $myldap > /etc/sysconfig/ldap
rm -f $myldap

#overlays
overlays=`make_temp`

old_overlays=`file $ldap_config_dir/cn=config module`
if [ -f "$old_overlays" ];then
#    rm -rf $old_overlays

    cat $overlays_modify_ldif>$overlays
    res=`cat $old_overlays|grep "back_monitor.la"`
    if [ "x$res" = "x" ];then
	echo "olcModuleLoad: {0}back_monitor.la">>$overlays
    fi

    res=`cat $old_overlays|grep "ppolicy.la"`
    if [ "x$res" = "x" ];then
	echo "olcModuleLoad: {1}ppolicy.la">>$overlays
    fi

    res=`cat $old_overlays|grep "syncprov.la"`
    if [ "x$res" = "x" ];then
	echo "olcModuleLoad: {2}syncprov.la">>$overlays
    fi

    ldapmodify -x -D "cn=config" -w $mypass -H ldap://localhost:389 -f $overlays > /dev/null

else
    cat $overlays_ldif>$overlays
    if [ "`uname -m`" = "x86_64" ]; then
	sed -i "s|^olcModulepath: .*|olcModulepath: /usr/lib64/openldap|g" $overlays
    fi
    ldapadd -x -D "cn=config" -w $mypass -H ldap://localhost:389 -f $overlays > /dev/null
fi

if [ $? -eq 0 ]; then 
    _T 0 $"%s overlays have been added successfully" "LDAP"
else 
    _T 2 $"%s overlays failed to add" "LDAP"
    _T 2 $"See %s for details" "/var/log/ldap/ldap.log"
    exit 1
fi
rm $overlays
check_ldap_config_critically "$ldap_config_dir"

##ppolicy overlay configuring
myppolicyldif=`make_temp`

bdb=`file $ldap_config_dir/cn=config bdb$`
if [ -d "$bdb" ]; then
    oldPpolicyFile=`file $bdb ppolicy.ldif`
    if [ -f "$oldPpolicyFile" ];then
	oldppolicy=1
    else
	oldppolicy=0
    fi
else
    oldppolicy=0
fi

cat $ppolicy_ldif_template | sed -e "\
s!@BDBDATABASE@!$bdb_ldif!g;
s!@SUFFIX@!$mysuffix!g"> $myppolicyldif

if [ "x$ppolicy" == "xon" ];then
    if [ "$oldppolicy" == "0" ]; then 
	ldapadd -x -D "cn=config" -w $mypass -H ldap://localhost:389 -f $myppolicyldif > /dev/null
	if [ $? -eq 0 ]; then 
	    _T 0 $"%s settings have been loaded successfully" "PPolicy"
	else 
	    _T 2 $"%s settings failed to load" "PPolicy"
	    _T 2 $"See %s for details" "/var/log/ldap/ldap.log"
	    exit 1
	fi    
    fi
fi
rm -f $myppolicyldif


#if ppolicy = 0
#we can't delete ppolicy module from cn=module{0},cn=config dynamically: current ldap doesn't support such ability
#if it is very required, then it would be done via <openldap dir>/slapd.d/cn=config/cn=module{0} modifying 

ldapmodify -x -D "cn=config" -w $mypass -H ldap://localhost:389 -f $certs_modify_ldif > /dev/null
if [ $? -eq 0 ]; then 
    _T 0 $"%s certificates have been registered successfully" "LDAP"
else 
    _T 2 $"%s certificates failed to register" "LDAP"
    _T 2 $"See %s for details" "/var/log/ldap/ldap.log"
    exit 1
fi

#indexes
ldapmodify -x -D "cn=config" -w $mypass -H ldap://localhost:389 -f $dbindex_ldif > /dev/null
if [ $? -eq 0 ]; then 
    _T 0 $"%s indexes have been added successfully" "LDAP"
else 
    _T 2 $"%s indexes failed to add" "LDAP"
    _T 2 $"See %s for details" "/var/log/ldap/ldap.log"
    exit 1
fi

check_ldap_config_critically "$ldap_config_dir"

# ACL
acl_file=`make_temp`

res=`cat $bdb_ldif|grep olcAccess`

if [ "x$res" = "x" ];then
    #echo "no ACLs"
    cat $acl_template | sed -e "\
    s/@SUFFIX@/$mysuffix/g;\
    s/@OPERATION@/add/g"> $acl_file
else
    #echo "ACLs exist"
    cat $acl_template | sed -e "\
    s/@SUFFIX@/$mysuffix/g;\
    s/@OPERATION@/replace/g"> $acl_file
fi

ldapmodify -x -D "cn=config" -w $mypass -H ldap://localhost:389 -f $acl_file > /dev/null
if [ $? -eq 0 ]; then 
    _T 0 $"%s have been added successfully" "LDAP ACLs"
else 
    _T 2 $"%s failed to add" "LDAP ACLs"
    _T 2 $"See %s for details" "/var/log/ldap/ldap.log"
    exit 1
fi

check_ldap_config_critically "$ldap_config_dir"
_T 0 $"%s configuration has been generated successfully" "LDAP"

rm $acl_file

# base LDIF
myldif=`make_temp`
cat $base_ldif_template | sed -e "\
	s/@SUFFIX@/$mysuffix/g;\
	s/@DC@/${mydomain%%.[a-zA-Z0-9]*}/g;\
	s/@DOMAIN@/${mydomain}/g;\
	s|@ldapadmin_password@|$pass|g" > $myldif

# dry run first
$SLAPADD -u -F $ldap_config_dir -b "$mysuffix" < $myldif
if [ $? -ne 0 ]; then
	_T 2 $"Initial %s database failed to load during test run" "LDAP"
	_T 2 $"%s file used: %s" "ldif" "$myldif"
	_T 2 $"%s configuration used: %s" "LDAP" "/etc/openldap/slapd.d"
	rm -f $myldapconf
	exit 1
else
    _T 0 $"Initial %s database loading test has been successful" "LDAP"
fi

# let's go for real now
do_service_action_critically slapd stop "/var/log/ldap/ldap.log"
do_service_action_critically mmc-agent stop "/var/log/mmc/mmc-agent.log"

backup_db=`mybackup_dir /var/lib/ldap`
clean_ldap_database "/var/lib/ldap"

#backup_slapd_conf=`mybackup /etc/openldap/slapd.conf`
backup_ldap_conf=`mybackup /etc/openldap/ldap.conf`
cat $myldapconf > /etc/openldap/ldap.conf
rm -f $myldapconf

$SLAPADD -b "$mysuffix" < $myldif
if [ $? -ne 0 ]; then
	_T 2 $"Initial %s database failed to load" "LDAP"
	_T 2 $"Your previous %s database directory has been backuped to %s" "LDAP" "$backup_db"
	_T 2 $"Your previous %s has been backuped to %s" "/etc/openldap/ldap.conf" "$backup_ldap_conf"
	exit 1
else
    _T 0 $"Initial %s database has been loaded successfully" "LDAP"
    _T 0 $"Your previous %s database directory has been backuped to %s" "LDAP" "$backup_db"
fi


chown ldap:ldap /var/lib/ldap/*

#LDAP auth configuration
#configure system to find users, groups etc in LDAP also
backup /etc/nsswitch.conf
cat $nsswitch_template > /etc/nsswitch.conf

pam_ldap_conf=/etc/pam_ldap.conf
#for mandriva dist this file /etc/ldap.conf

backup $pam_ldap_conf
cat $pam_ldap_conf_template > $pam_ldap_conf
sed -i "s/\@SUFFIX\@/$mysuffix/" $pam_ldap_conf
sed -i "s/\@SERVER\@/127.0.0.1/" $pam_ldap_conf

#setting base dn for nslcd daemon
#do not need for mandriva
backup $nslcd_conf
cat $nslcd_conf_template > $nslcd_conf
sed -i "s/\@BASE_DN\@/$mysuffix/" $nslcd_conf

do_service_action_critically slapd start "/var/log/ldap/ldap.log"
do_service_action_critically mmc-agent start "/var/log/mmc/mmc-agent.log"
do_service_action_critically httpd restart "/var/log/httpd/error_log"
do_service_action_critically nslcd restart

#adding to autorun
chkconfig slapd on
chkconfig httpd on
chkconfig mmc-agent on
chkconfig nslcd on

_T 8 $"%s is running" "ROSA Directory Server"
_T 8 $"You can log in the %s interface from %s" "RDS" "http://@HOSTNAME@/mmc/"
_T 8 $"%s administrator: %s" "RDS" "root"
# echo "7RDS administrator #password : $mypass"

exit 0

