# -*- coding: UTF-8 -*-
#

#
# $Id$
#
# This file is part of ROSA Server Setup
#
# RSS is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# RSS is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with RSS; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
# MA 02110-1301, USA.

import re
import os
import commands
from mss.agent.lib.utils import getINIoption

def get_config_info():
    return ("setup-mmc.sh", ['mdshostname', 'mdsfqdn', 'mdsipaddress', 'mdsdomain', 'mdspasswd', 'mdsppolicy', 'mdsbackupdir'])

def get_current_config():
    ini='/etc/mmc/plugins/base.ini'
    if os.path.exists(ini):
        mdsdomain = getINIoption('ldap', 'baseDN', ini)
        mdsdomain = re.sub('^dc=', '', mdsdomain)
        mdsdomain = re.sub(',[\s]*dc=', '.', mdsdomain)
        if getINIoption('main', 'disable', '/etc/mmc/plugins/ppolicy.ini') == "0":
            mdsppolicy = "on"
        else:
            mdsppolicy = "off"

        mdsfqdn = commands.getoutput("/bin/hostname -f")
        if len(mdsfqdn) == 0 or mdsfqdn.startswith('hostname:'):
            mdsfqdn = get_host_name()

        mdsbackupdir = getINIoption('backup-tools', 'destpath', ini)

        return {'mdsdomain': mdsdomain, "mdsppolicy": mdsppolicy, 'mdsfqdn': mdsfqdn, 'mdsbackupdir' : mdsbackupdir}
    else:
        return {}

def get_ip_addresses():
    ips = commands.getoutput("/sbin/ifconfig | grep -i \"inet\" | grep -iv \"inet6\" | " +
                          "awk {'print $2'} | sed -ne 's/addr\:/ /p'")
    result = list({'name' : ip, 'value' : ip} for ip in ips.split())
    return result

def get_host_name():
    hostname = ''
    hostname = commands.getoutput("/bin/hostname")
    if len(hostname) == 0:
        hostname = 'host.example.com'
    return hostname

def get_backup_dir():
    ini='/etc/mmc/plugins/base.ini'
    if os.path.exists(ini):
        return getINIoption('backup-tools', 'destpath', ini)
    else:
        return '/var/archives/'
