#!/bin/bash

. ../functions.sh
set_locale_settings

userquota_tpl="templates/userquota.ini.tpl"

fss=$1
has_xfs=0

backup /etc/fstab
for f in $fss; do
    dev=`echo $f | cut -d: -f1`
    uuid=`dumpe2fs $dev 2>/dev/null | grep UUID | awk '{ print $3 }'`
    
    uuid_string=`grep "^UUID=${uuid}" /etc/fstab`
    if [ "$uuid_string" ]; then
	mountpoint=`echo "$uuid_string" | sed "s/^UUID=${uuid}[[:space:]]\+\([^ ]\+\).*$/\1/"`
	fs=`echo "$uuid_string" | sed "s/^UUID=${uuid}[[:space:]]\+[^ ]\+[[:space:]]\+\([^ ]\+\).*$/\1/"`    
	echo "$uuid_string" | grep -q usrquota
	has_quota=$?
    else
	dev_string=`grep "^$dev" /etc/fstab`
	if  [ "$dev_string" ]; then
	    mountpoint=`echo "$dev_string" | sed "s/\s*\S*[[:space:]]\+\([^ ]\+\).*$/\1/"`
	    fs=`echo "$dev_string" | sed "s/\s*\S*[[:space:]]\+[^ ]\+[[:space:]]\+\([^ ]\+\).*$/\1/"`
	    echo "$dev_string" | grep -q usrquota
	    has_quota=$?
	else
	    _T 0 $"No device description in %s for %s" /etc/fstab "$dev" 
	    continue
	fi
	
    fi
    
    if [ $has_quota -ne 0 ]; then
        if  [ "$uuid_string" ]; then
    	    sed -i "s/^\(UUID=${uuid}[[:space:]]\+[^ ]\+[[:space:]]\+[^ ]\+[[:space:]]\+\)\([^ ]\+\)\(.*\)$/\1\2,usrquota\3/" /etc/fstab
    	else
    	    sed -i "s|^\(${dev}[[:space:]]\+[^ ]\+[[:space:]]\+[^ ]\+[[:space:]]\+\)\([^ ]\+\)\(.*\)$|\1\2,usrquota\3|" /etc/fstab
    	fi
    	if [ $? -ne 0 ]; then
    	    _T 1 $"Failed to add %s option for %s" usrquota "$mountpoint"
    	    continue
	fi
    	_T 0 $"%s option has been added for %s" usrquota "$mountpoint"
    fi
    
    if [ "$fs" == "ext3" ] || [ "$fs" == "ext4" ] ; then
        mount -o remount,usrquota "$mountpoint" 2>/dev/null
        if [ $? -ne 0 ]; then
	    _T 1 $"Failed to remount %s" "$mountpoint"
        fi
        #quotaoff -vu "$mountpoint" > /dev/null 2>&1
        quotacheck -cum "$mountpoint" > /dev/null 2>&1
        quotaon -uv "$mountpoint" > /dev/null 2>&1
        _T 7 $"Quotas have been activated on %s" $mountpoint
        
    elif [ "$fs" == "xfs" ]; then
        _T 7 $"Quotas have been activated on %s" $mountpoint
        has_xfs=1
    else
        _T 1 $"Quotas are not supported on this filesystem: %s" $fs
        continue
    fi
    
    tmp=`echo $f | sed "s/:/:1024:/"`

    filesystems=${filesystems}${tmp}","
done

if [ $has_xfs -eq 1 ];then
    _T 7 $"Restart the system to activate quotas"
fi

# install template
backup /etc/mmc/plugins/userquota.ini
cat $userquota_tpl > /etc/mmc/plugins/userquota.ini
sed -i "s!\@FILESYSTEMS\@!${filesystems%?}!" /etc/mmc/plugins/userquota.ini

do_service_action_critically mmc-agent restart /var/log/mmc/mmc-agent.log

_T 8 $"%s module has been activated in the %s interface" Quota RDS
_T 7 $"You can configure user quotas from the %s interface: %s" RDS http://@HOSTNAME@/mmc/

exit 0
