#!/bin/bash
if [ "`id -u`" != "0" ]; then
	echo "Error, must be root user"
	exit 1
fi

. '../functions.sh'

set_locale_settings

serverid=$1
replicatorpass=$2

basedn=`get_ldap_base_dn`
adminpass=`get_ldap_admin_password`

replicacfg="/etc/mmc/replica/replica.cfg"
replicaini="/etc/mmc/plugins/ldapreplica.ini"

replicatordn="uid=LDAP Replicator,ou=System Accounts,$basedn"

#setting a password for an LDAP replicator
ldappasswd -D "uid=LDAP Admin, ou=System Accounts, $basedn" -w "$adminpass" -s "$replicatorpass" "uid=LDAP Replicator, ou=System Accounts, $basedn"
if [ $? -eq 0 ]; then
    _T 0 $"The replicator user password has been changed"
else
    _T 2 $"Failed to change the replicator user password"
    exit 1
fi

#setting the server ID
temp=`make_temp`
cat templates/server-id.ldif.tpl > $temp
sed -i "s/@SERVER_ID@/$serverid/" $temp

ldapmodify -x -D "cn=config" -w $adminpass -H ldap://localhost:389 -f $temp
res=$?
rm -f $temp

if [ $res -eq 0 ]; then 
    _T 0 $"The server identifier has been set"
else
    _T 2 $"Failed to set the server identifier"
    exit 1
fi


#adding the syncrpov overlay to the list of loaded modules
res=`ldapsearch -x -D "cn=config" -w $adminpass -b "cn=config" "(objectClass=olcModuleList)" olcModuleLoad | grep syncprov.la`
if [ "$res" ]; then
    _T 0 $"The %s overlay is already present" syncprov
else
    #TO DO: this is code to detect a dn for olcModuleList entry to do overlay adding a more adaptable.
	#ss="dn: "
	#module_list_dn=`ldapsearch -x -D "cn=config" -w $adminpass -b "cn=config" "(objectClass=olcModuleList)"| grep "$ss" | cut -c ${#ss}-`
	#echo $module_list_entry_dn
    ldapmodify -x -D "cn=config" -w $adminpass -H ldap://localhost:389 -f templates/syncprov-add.ldif
    if [ $? -eq 0 ]; then 
        _T 0 $"The %s overlay has been added" syncprov
    else
	_T 2 $"Failed to add the %s overlay" syncprov
	exit 1
    fi
fi

#configuring syncrpov module
res=`ldapsearch -x -D "cn=config" -w $adminpass -b "cn=config" "(objectClass=olcSyncProvConfig)" objectClass | grep olcOverlayConfig`
if [ "$res" ]; then
    _T 0 $"The %s overlay is already configured" syncprov
else
    #TO DO: this is code to detect a dn for olcModuleList entry to do overlay adding a more adaptable.
	#ss="dn: "
	#module_list_dn=`ldapsearch -x -D "cn=config" -w $adminpass -b "cn=config" "(objectClass=olcModuleList)"| grep "$ss" | cut -c ${#ss}-`
	#echo $module_list_entry_dn
    ldapmodify -x -D "cn=config" -w $adminpass -H ldap://localhost:389 -f templates/syncprov-config.ldif
    if [ $? -eq 0 ]; then 
        _T 0 $"The %s overlay has been configured" syncprov
    else
	_T 2 $"Failed to configure the %s overlay" syncprov
	exit 1
    fi
fi

#backup /etc/mmc/plugins/replication.ini
#cat templates/replication.ini.tpl > /etc/mmc/plugins/replication.ini
#sed -i "s/\@REPLICATOR_DN\@/$replicatordn/" /etc/mmc/plugins/replication.ini

backup $replicaini
#base_dn=`ldapsearch -x -s base objectclass=* -LLL|grep dn|awk -F ' ' '{print $2}'`
cat templates/ldapreplica.ini.tpl | sed -e "\
s/@SUFFIX@/$basedn/g" > $replicaini

mkdir /etc/mmc/replica
#cat templates/replica/agent.cfg.tpl > /etc/mmc/replica/agent.cfg
backup $replicacfg

domain=`hostname -d`
if [ -z "$domain" ]; then
    _T 0 $"Failed to get domain name of the server host" 
    domain="example.com"
fi

cat templates/replica/replica.cfg.tpl | sed -e "\
s/@SUFFIX@/$basedn/;\
s/@DOMAIN@/$domain/g" > $replicacfg


do_service_action_critically mmc-agent restart "/var/log/mmc/mmc-agent.log"

_T 8 $"%s has been configured for replication" LDAP
_T 8 $"You can select and configure the replicated objects using the %s interface: %s" RDS "http://@HOSTNAME@/mmc/"

exit 0
