#!/bin/bash
# Copyright Mandriva 2009, 2010 all rights reserved

if [ "`id -u`" != "0" ]; then
	echo "1Error, must be root user"
	exit 1
fi

oldifs=$IFS ; IFS=$'\n' ; os_info=(`../os_info.sh`) ; IFS=$oldifs 
dist=${os_info[2]}

. ../functions.sh
set_locale_settings
check_host_fqdn

base_smb_template="templates/smb.conf.tpl"
smbldap_bind_template="templates/smbldap_bind.conf.tpl"
smbldap_template="templates/smbldap.conf.tpl"
mds_smb_template="templates/samba.ini.tpl"

mdssuffix=`get_ldap_base_dn`
mdspass=`get_ldap_admin_password`
mdspass_e=`escape_sed $mdspass`
mdsserver=127.0.0.1

smbdomain="$1"
smbnetbios="$2"
smbadmin="$3"
smbpass="$4"

#getting old domain
old_smbdomain=""
smbdomain_data=`ldapsearch -x -LLL -b "$mdssuffix" "(SambaDomainName=*)" SambaDomainName`
if [ "$smbdomain_data" ]; then
    old_smbdomain=`echo "$smbdomain_data" | grep -i '^sambadomainname' -m 1 | sed 's/^.*\:[[:space:]]\+//'`
fi

if [ "$old_smbdomain" ]; then
    if [ "$smbdomain" != "$old_smbdomain" ]; then
        ldapmodrdn -x -r -w "$mdspass" -D "uid=LDAP Admin,ou=System Accounts,$mdssuffix" "sambaDomainName=$old_smbdomain,$mdssuffix" "sambaDomainName=$smbdomain"
    fi
fi


#### Now /etc/samba/smb.conf
if [ "`uname -m`" = "x86_64" ]; then
    scripts_dir=/usr/lib64/mmc
else
    scripts_dir=/usr/lib/mmc
fi

backup /etc/samba/smb.conf
cat $base_smb_template > /etc/samba/smb.conf
sed -i "s/\@SUFFIX\@/$mdssuffix/" /etc/samba/smb.conf
sed -i "s/\@WORKGROUP\@/$smbdomain/" /etc/samba/smb.conf
sed -i "s/\@NETBIOSNAME\@/$smbnetbios/" /etc/samba/smb.conf
sed -i "s|\@SCRIPTS_DIR\@|$scripts_dir|" /etc/samba/smb.conf

$(dirname $0)/setup-mmc-smb.py

smbpasswd -w $mdspass > /dev/null
if [ $? -eq 0 ]; then 
    _T 0 $"%s password has been set" samba
else 
    _T 2 $"Failed to set %s password" samba 
    exit 1
fi

do_service_action_critically smb restart

sid=`net getlocalsid $smbdomain | cut -d ':' -f2 | cut -d ' ' -f2`

#sid updating for a case when netbios name changes
if [ "$sid" ]; then
    net setlocalsid "$sid"
fi

#check whether ppolicy is configured
ldapsearch -x -LLL -b "cn=default,ou=password policies,$mdssuffix" > /dev/null 2>&1
if [ $? -eq 0 ]; then
    is_ppolicy_configured=1
    pass_encryption="CLEARTEXT"
else
    is_ppolicy_configured=0
    pass_encryption="SSHA"
fi


###### now /etc/smbldap-tools/smbldap.conf
backup /etc/smbldap-tools/smbldap.conf
cat $smbldap_template > /etc/smbldap-tools/smbldap.conf
sed -i "s/\@SUFFIX\@/$mdssuffix/" /etc/smbldap-tools/smbldap.conf
sed -i "s/\@WORKGROUP\@/$smbdomain/" /etc/smbldap-tools/smbldap.conf
sed -i "s/\@SID\@/$sid/" /etc/smbldap-tools/smbldap.conf
sed -i "s/\@SERVER\@/$mdsserver/" /etc/smbldap-tools/smbldap.conf
sed -i "s/\@PASSWORD_ENCRYPTION\@/$pass_encryption/" /etc/smbldap-tools/smbldap.conf


###### now /etc/smbldap-tools/smbldap_bind.conf
backup /etc/smbldap-tools/smbldap_bind.conf
cat $smbldap_bind_template > /etc/smbldap-tools/smbldap_bind.conf 
sed -i "s/\@SUFFIX\@/$mdssuffix/" /etc/smbldap-tools/smbldap_bind.conf
sed -i "s/\@PASSWORD\@/$mdspass_e/" /etc/smbldap-tools/smbldap_bind.conf

populate_errors=`make_temp`

echo -e "$smbpass\n$smbpass" | smbldap-populate -m 512 -k 512 -a "$smbadmin" 2>$populate_errors
if [ $? -eq 0 ]; then 
    _T 0 $"%s has been populated by %s entries" LDAP samba
else
    _T 2 $"Failed to populate %s by %s entries" LDAP samba
    exit 1
fi
cat $populate_errors

errors_size=`stat --printf="%s" $populate_errors`
if [[ ("$errors_size" != "0") && ("$is_ppolicy_configured" == "1") ]]; then
    cat $populate_errors | grep "Failed to modify UNIX password" | grep "smbldap-passwd" > /dev/null
    if [ $? -eq 0 ]; then 
	_T 1 $"%s password for user %s can't be set due to the settings of %s password policy" UNIX $smbadmin \'default\'
	_T 1 $"You can modify this settings or choose another password for user %s here: %s" $smbadmin http://@HOSTNAME@/mmc/
    fi
fi

rm -f $populate_errors

do_service_action_critically smb restart

###### now /etc/mmc/plugins/samba.ini
if [ "`uname -m`" = "x86_64" ]; then
    clamav_lib=/usr/lib64/samba/vfs/vscan-clamav.so
else
    clamav_lib=/usr/lib/samba/vfs/vscan-clamav.so
fi

backup /etc/mmc/plugins/samba.ini
cat $mds_smb_template > /etc/mmc/plugins/samba.ini
sed -i "s/\@SUFFIX\@/$mdssuffix/" /etc/mmc/plugins/samba.ini
sed -i "s|@CLAMAV_LIB\@|$clamav_lib|" /etc/mmc/plugins/samba.ini

echo "0RDS samba configuration done.";

sed -i "s/^defaultUserGroup = users$/defaultUserGroup = Domain Users/" /etc/mmc/plugins/base.ini
if [ $? -eq 0 ]; then 
    _T 7 $"Users will be created in the %s group by default. Your early created users still remain in the %s group" "Domain Users" users
fi

# create directories
mkdir -p /home/samba/netlogon
mkdir -p /home/samba/shares/public
chown "root:Domain Users" /home/samba/shares/public
mkdir -p /home/samba/profiles
chown "root:Domain Users" /home/samba/profiles
chmod 770 /home/samba/profiles

do_service_action_critically mmc-agent restart /var/log/mmc/mmc-agent.log

# "Command below requires some delay on Mandriva OS. Otherwise, it doesn't work."
if [ "$dist" = "Mandriva" ] ; then
    sleep 20
fi
net rpc rights grant "$smbdomain\Domain Admins" SeMachineAccountPrivilege -S $mdsserver -U $smbadmin%$smbpass > /dev/null 2>&1
if [ $? -eq 0 ]; then 
    _T 0 $"Rights have been granted for the %s group" "Domain Admins"
else 
    _T 2 $"Failed to grant rigths for the %s group" "Domain Admins"
    exit 1
fi


# ACL test
touch /home/samba/test
setfacl -m g:"Domain Users":rx /home/samba/test > /dev/null 2>&1
if [ $? -ne 0 ]; then 
    _T 1 $"Your filesystem does not support %s. You won't be able to set % on %s shares" ACL ACLs samba
    _T 1 $"For %s filesystem you have to add the %s option in %s" ext3 acl /etc/fstab
else 
    _T 0 $"%s are supported by your filesystem" ACLs
fi
rm -f /home/samba/test

do_service_action_critically smb restart
if [ "$dist" = "ROSA Enterprise Linux Server" ] || [ "$dist" = "CentOS" ] ; then
    do_service_action_critically nmb restart
fi

# adding to autorun
if [ "$dist" = "ROSA Enterprise Linux Server" ] || [ "$dist" = "CentOS" ] ; then
    chkconfig nmb on
fi
chkconfig smb on

# confirmation
_T 8 $"Domain name: %s" $smbdomain
_T 8 $"Server name: %s" $smbnetbios
_T 8 $"Domain administrator: %s" $smbadmin
_T 7 $"Public share has been created in %s" /home/samba/shares/public
#_T 7 $"- you can create a logon.bat script in /home/samba/netlogon"
_T 8 $"Make sure you have enabled %s services on your firewall" samba
_T 7 $"Profiles are disabled by default"
_T 7 $"- edit %s manually to activate them" /etc/samba/smb.conf
_T 8 $"You can use the %s interface to manage your users and shares: %s" RDS http://@HOSTNAME@/mmc/

exit 0
