#!/bin/sh

# Copyright (C) 2002 MySQL AB and Jeremy Cole
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

. ../functions.sh

#config=".my.cnf.$$"
#command=".mysql.$$"

mysql_config="/etc/my.cnf"

set_locale_settings

trap "interrupt" 2

interrupt(){
    mysql_cleanup
    exit 1
}

check_root_password() {
    mysql_check_root_password "$1"
    if [ $? -ne 0 ]; then
	_T 2 $"Typed %s %s password is not valid" "MySQL" "root"
	interrupt
    fi
}

set_root_password() {
    local rootpass=$1
    local esc_pass=`mysql_basic_single_escape "$rootpass"`
    mysql_do_query "UPDATE mysql.user SET Password=PASSWORD('$esc_pass') WHERE User='root';" 2>/dev/null
    res=$?
    if [ $res -eq 0 ]; then
	_T 0 $"%s password has been updated successfully" "root"
	reload_privilege_tables || exit 1
	mysql_make_config "$rootpass"
    else
	_T 2 $"Failed to update %s password" "root"
	interrupt
    fi
    return $res
}

remove_anonymous_users() {
    mysql_do_query "DELETE FROM mysql.user WHERE User='';"
    res=$?
    if [ $res -eq 0 ]; then
	_T 0 $"Anonymous users have been deleted"
    else
	_T 2 $"Failed to delete anonymous users"
	interrupt
    fi
    return $res
}

remove_remote_root() {
    mysql_do_query "DELETE FROM mysql.user WHERE User='root' AND Host!='localhost';" 2>/dev/null
    res=$?
    if [ $res -eq 0 ]; then
	_T 0 $"Remotely %s login has been disallowed" "root"
    else
	_T 1 $"Failed to deny remotely %s login" "root"
    fi
    return $res
}

remove_test_database() {
    mysql_do_query "DROP DATABASE test;" 2>/dev/null
    if [ $? -eq 0 ]; then
	_T 0 $"Test database has been removed"
    else
    	_T 1 $"Failed to remove a test database"
    fi

    mysql_do_query "DELETE FROM mysql.db WHERE Db='test' OR Db='test\\_%'" 2>/dev/null
    if [ $? -eq 0 ]; then
    	_T 0 $"Test database privileges have been removed"
    else
    	_T 1 $"Failed to remove the test database privileges"
    fi
}

reload_privilege_tables() {
    mysql_do_query "FLUSH PRIVILEGES;"
    res=$?
    if [ $res -eq 0 ]; then
    	_T 0 $"Privilage tables have been reloaded"

    else
    	_T 0 $"Failed to reload the privilage tables"
    fi
    return $res
}

# The actual script starts here
do_service_action mysqld restart
mysql_prepare
# set mysql character set to utf8
backup $mysql_config

has_default_collation=`cat /etc/my.cnf|grep "^default-collation"`
tmp=`make_temp`

if [ "x$has_default_collation" = "x" ]; then
    cat $mysql_config | sed -e '/^user=/a\default-collation=utf8_general_ci' >> $tmp
else
    cat $mysql_config | sed 's/^default-collation=.*$/default-collation=utf8_general_ci/g'>> $tmp
fi
cat $tmp > $mysql_config
echo '' > $tmp

has_default_charset=`cat /etc/my.cnf|grep "^default-character-set"`
if [ "x$has_default_charset" = "x" ]; then
    cat $mysql_config | sed -e '/^user=/a\default-character-set=utf8' >> $tmp
else
    cat $mysql_config | sed 's/^default-character-set=.*$/default-character-set=utf8/g' >> $tmp
fi

cat $tmp > $mysql_config


check_root_password "$1"
set_root_password "$2"
remove_anonymous_users
remove_remote_root
remove_test_database
reload_privilege_tables

mysql_cleanup

chkconfig mysqld on

_T 8 $"%s has been configured" "MySQL"
_T 8 $"%s is running" "MySQL"

exit 0
